@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: Glyphs.java 924674 2010-03-18 09:41:26Z jeremias $ */
+/* $Id: Glyphs.java 1681108 2015-05-22 13:26:12Z ssteiner $ */
 
 package org.apache.xmlgraphics.fonts;
 
@@ -34,7 +34,10 @@ import org.apache.commons.io.IOUtils;
 /**
  * This class provides a number of constants for glyph management.
  */
-public class Glyphs {
+public final class Glyphs {
+
+    private Glyphs() {
+    }
 
     /**
      * Glyph name for the "notdef" glyph
@@ -43,10 +46,14 @@ public class Glyphs {
 
     /**
      * Glyph names for Mac encoding
+     * @deprecated That array was supposed to represent the standard Macintosh ordering
+     *      of glyphs in a TrueType font (it does NOT correspond to the MacRoman encoding).
+     *      In addition some entries are incorrect.
      */
+    @Deprecated
     public static final String[] MAC_GLYPH_NAMES = {
         /* 0x00 */
-        NOTDEF, ".null", "CR", "space", "exclam", "quotedbl", "numbersign",
+        Glyphs.NOTDEF, ".null", "CR", "space", "exclam", "quotedbl", "numbersign",
                 "dollar", "percent", "ampersand", "quotesingle", "parenleft",
                 "parenright", "asterisk", "plus", "comma", /* 0x10 */
         "hyphen", "period", "slash", "zero", "one", "two", "three", "four",
@@ -646,22 +653,26 @@ public class Glyphs {
         List lines = new java.util.ArrayList();
         InputStream in = Glyphs.class.getResourceAsStream(filename);
         if (in == null) {
-            throw new Error("Cannot load " + filename
+            throw new RuntimeException("Cannot load " + filename
                     + ". The Glyphs class cannot properly be initialized!");
         }
         try {
             BufferedReader reader = new BufferedReader(new InputStreamReader(in, "US-ASCII"));
             String line;
-            while ((line = reader.readLine()) != null) {
-                if (!line.startsWith("#")) {
-                    lines.add(line);
+            try {
+                while ((line = reader.readLine()) != null) {
+                    if (!line.startsWith("#")) {
+                        lines.add(line);
+                    }
                 }
+            } finally {
+                reader.close();
             }
         } catch (UnsupportedEncodingException uee) {
-            throw new Error("Incompatible JVM! US-ASCII encoding is not supported."
+            throw new RuntimeException("Incompatible JVM! US-ASCII encoding is not supported."
                     + " The Glyphs class cannot properly be initialized!");
         } catch (IOException ioe) {
-            throw new Error("I/O error while loading " + filename
+            throw new RuntimeException("I/O error while loading " + filename
                     + ". The Glyphs class cannot properly be initialized!");
         } finally {
             IOUtils.closeQuietly(in);
@@ -708,7 +719,7 @@ public class Glyphs {
      * @param ch glyph to evaluate
      * @return the name of the glyph
      */
-    public static final String charToGlyphName(char ch) {
+    public static String charToGlyphName(char ch) {
         return stringToGlyph(Character.toString(ch));
     }
 
@@ -717,7 +728,7 @@ public class Glyphs {
      * @param glyphName the glyph name
      * @return the Unicode sequence of the glyph (or null if the glyph name is unknown)
      */
-    public static final String getUnicodeSequenceForGlyphName(String glyphName) {
+    public static String getUnicodeSequenceForGlyphName(String glyphName) {
         //Mapping: see http://www.adobe.com/devnet/opentype/archives/glyph.html
         //Step 1
         int period = glyphName.indexOf('.');
@@ -787,7 +798,8 @@ public class Glyphs {
      * @deprecated User getUnicodeCodePointsForGlyphName instead. This method only returns the
      *          first Unicode code point it finds.
      */
-    public static final String glyphToString(String name) {
+    @Deprecated
+    public static String glyphToString(String name) {
         for (int i = 0; i < UNICODE_GLYPHS.length; i += 2) {
             if (UNICODE_GLYPHS[i + 1].equals(name)) {
                 return UNICODE_GLYPHS[i];
