@@ -15,20 +15,27 @@
  * limitations under the License.
  */
 
-/* $Id: PNGEncodeParam.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: PNGEncodeParam.java 1681137 2015-05-22 14:54:05Z ssteiner $ */
 
 package org.apache.xmlgraphics.image.codec.png;
 
-import org.apache.xmlgraphics.image.codec.util.ImageEncodeParam;
-import org.apache.xmlgraphics.image.codec.util.PropertyUtil;
-
 import java.awt.image.ColorModel;
 import java.awt.image.IndexColorModel;
 import java.awt.image.RenderedImage;
 import java.awt.image.SampleModel;
+import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
-import java.util.ArrayList;
+
+import org.apache.xmlgraphics.image.codec.util.ImageEncodeParam;
+import org.apache.xmlgraphics.image.codec.util.PropertyUtil;
+
+// CSOFF: MemberName
+// CSOFF: MultipleVariableDeclarations
+// CSOFF: NeedBraces
+// CSOFF: OperatorWrap
+// CSOFF: ParameterName
+// CSOFF: WhitespaceAround
 
 /**
  * An instance of <code>ImageEncodeParam</code> for encoding images in
@@ -38,6 +45,7 @@ import java.util.ArrayList;
  * be removed or changed in future releases of JAI.</b>
  */
 public abstract class PNGEncodeParam implements ImageEncodeParam {
+    private static final long serialVersionUID = -7851509538552141263L;
 
     /** Constant for use with the sRGB chunk. */
     public static final int INTENT_PERCEPTUAL = 0;
@@ -103,12 +111,14 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
     public static class Palette extends PNGEncodeParam {
 
+        private static final long serialVersionUID = -5181545170427733891L;
+
         /** Constructs an instance of <code>PNGEncodeParam.Palette</code>. */
-        public Palette() {}
+        public Palette() { }
 
         // bKGD chunk
 
-        private boolean backgroundSet = false;
+        private boolean backgroundSet;
 
         /**
          * Suppresses the 'bKGD' chunk from being output.
@@ -130,8 +140,8 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
          * <code>IllegalArgumentException</code> will be thrown.
          */
         public void setBitDepth(int bitDepth) {
-            if (bitDepth != 1 && bitDepth != 2 && bitDepth != 4 &&
-                bitDepth != 8) {
+            if (bitDepth != 1 && bitDepth != 2 && bitDepth != 4
+                && bitDepth != 8) {
                 throw new IllegalArgumentException(PropertyUtil.getString("PNGEncodeParam2"));
             }
             this.bitDepth = bitDepth;
@@ -140,8 +150,8 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
         // PLTE chunk
 
-        private int[] palette = null;
-        private boolean paletteSet = false;
+        private int[] palette;
+        private boolean paletteSet;
 
         /**
          * Sets the RGB palette of the image to be encoded.
@@ -155,7 +165,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
          * @param rgb An array of <code>int</code>s.
          */
         public void setPalette(int[] rgb) {
-            if (rgb.length < 1*3 || rgb.length > 256*3) {
+            if (rgb.length < 1 * 3 || rgb.length > 256 * 3) {
                 throw new
                   IllegalArgumentException(PropertyUtil.getString("PNGEncodeParam0"));
             }
@@ -273,12 +283,14 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
     public static class Gray extends PNGEncodeParam {
 
+        private static final long serialVersionUID = -2055439792025795274L;
+
         /** Constructs an instance of <code>PNGEncodeParam.Gray</code>. */
-        public Gray() {}
+        public Gray() { }
 
         // bKGD chunk
 
-        private boolean backgroundSet = false;
+        private boolean backgroundSet;
 
         /**
          * Suppresses the 'bKGD' chunk from being output.
@@ -305,9 +317,9 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
          * values will be shifted and left-filled with zeroes.
          */
         public void setBitDepth(int bitDepth) {
-            if (bitDepth != 1 && bitDepth != 2 && bitDepth != 4 &&
-                bitDepth != 8 && bitDepth != 16) {
-                throw new IllegalArgumentException();
+            if (bitDepth != 1 && bitDepth != 2 && bitDepth != 4
+                && bitDepth != 8 && bitDepth != 16) {
+                throw new IllegalArgumentException(PropertyUtil.getString("PNGEncodeParam2"));
             }
             this.bitDepth = bitDepth;
             bitDepthSet = true;
@@ -381,7 +393,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
         }
 
         private int bitShift;
-        private boolean bitShiftSet = false;
+        private boolean bitShiftSet;
 
         /**
          * Sets the desired bit shift for a grayscale image.
@@ -391,7 +403,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
          */
         public void setBitShift(int bitShift) {
             if (bitShift < 0) {
-                throw new RuntimeException();
+                throw new IllegalArgumentException(PropertyUtil.getString("PNGEncodeParam25"));
             }
             this.bitShift = bitShift;
             bitShiftSet = true;
@@ -437,12 +449,14 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
     public static class RGB extends PNGEncodeParam {
 
+        private static final long serialVersionUID = -8918762026006670891L;
+
         /** Constructs an instance of <code>PNGEncodeParam.RGB</code>. */
-        public RGB() {}
+        public RGB() { }
 
         // bKGD chunk
 
-        private boolean backgroundSet = false;
+        private boolean backgroundSet;
 
         /**
          * Suppresses the 'bKGD' chunk from being output.
@@ -464,7 +478,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
          */
         public void setBitDepth(int bitDepth) {
             if (bitDepth != 8 && bitDepth != 16) {
-                throw new RuntimeException();
+                throw new IllegalArgumentException(PropertyUtil.getString("PNGEncodeParam26"));
             }
             this.bitDepth = bitDepth;
             bitDepthSet = true;
@@ -482,7 +496,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
          */
         public void setBackgroundRGB(int[] rgb) {
             if (rgb.length != 3) {
-                throw new RuntimeException();
+                throw new IllegalArgumentException(PropertyUtil.getString("PNGEncodeParam27"));
             }
             backgroundRGB = rgb;
             backgroundSet = true;
@@ -538,7 +552,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
     }
 
     protected int bitDepth;
-    protected boolean bitDepthSet = false;
+    protected boolean bitDepthSet;
 
     /**
      * Sets the desired bit depth of an image.
@@ -570,7 +584,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
         bitDepthSet = false;
     }
 
-    private boolean useInterlacing = false;
+    private boolean useInterlacing;
 
     /**
      * Turns Adam7 interlacing on or off.
@@ -621,8 +635,8 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
     // cHRM chunk
 
-    private float[] chromaticity = null;
-    private boolean chromaticitySet = false;
+    private float[] chromaticity;
+    private boolean chromaticitySet;
 
     /**
      * Sets the white point and primary chromaticities in CIE (x, y)
@@ -637,7 +651,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
      */
     public void setChromaticity(float[] chromaticity) {
         if (chromaticity.length != 8) {
-            throw new IllegalArgumentException();
+            throw new IllegalArgumentException(PropertyUtil.getString("PNGEncodeParam28"));
         }
         this.chromaticity = (float[])(chromaticity.clone());
         chromaticitySet = true;
@@ -699,7 +713,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
     // gAMA chunk
 
     private float gamma;
-    private boolean gammaSet = false;
+    private boolean gammaSet;
 
     /**
      * Sets the file gamma value for the image.
@@ -742,8 +756,8 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
     // hIST chunk
 
-    private int[] paletteHistogram = null;
-    private boolean paletteHistogramSet = false;
+    private int[] paletteHistogram;
+    private boolean paletteHistogramSet;
 
     /**
      * Sets the palette histogram to be stored with this image.
@@ -789,8 +803,8 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
     // iCCP chunk
 
-    private byte[] ICCProfileData = null;
-    private boolean ICCProfileDataSet = false;
+    private byte[] iccProfileData;
+    private boolean iccProfileDataSet;
 
     /**
      * Sets the ICC profile data to be stored with this image.
@@ -798,9 +812,9 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
      *
      * <p> The 'iCCP' chunk will encode this information.
      */
-    public void setICCProfileData(byte[] ICCProfileData) {
-        this.ICCProfileData = (byte[])(ICCProfileData.clone());
-        ICCProfileDataSet = true;
+    public void setICCProfileData(byte[] iccProfileData) {
+        this.iccProfileData = (byte[])(iccProfileData.clone());
+        iccProfileDataSet = true;
     }
 
     /**
@@ -812,31 +826,31 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
      * @throws IllegalStateException if the ICC profile is not set.
      */
     public byte[] getICCProfileData() {
-        if (!ICCProfileDataSet) {
+        if (!iccProfileDataSet) {
             throw new IllegalStateException(PropertyUtil.getString("PNGEncodeParam15"));
         }
-        return (byte[])(ICCProfileData.clone());
+        return (byte[])(iccProfileData.clone());
     }
 
     /**
      * Suppresses the 'iCCP' chunk from being output.
      */
     public void unsetICCProfileData() {
-        ICCProfileData = null;
-        ICCProfileDataSet = false;
+        iccProfileData = null;
+        iccProfileDataSet = false;
     }
 
     /**
      * Returns true if a 'iCCP' chunk will be output.
      */
     public boolean isICCProfileDataSet() {
-        return ICCProfileDataSet;
+        return iccProfileDataSet;
     }
 
     // pHYS chunk
 
-    private int[] physicalDimension = null;
-    private boolean physicalDimensionSet = false;
+    private int[] physicalDimension;
+    private boolean physicalDimensionSet;
 
     /**
      * Sets the physical dimension information to be stored with this
@@ -901,8 +915,8 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
     // sPLT chunk
 
-    private PNGSuggestedPaletteEntry[] suggestedPalette = null;
-    private boolean suggestedPaletteSet = false;
+    private PNGSuggestedPaletteEntry[] suggestedPalette;
+    private boolean suggestedPaletteSet;
 
     /**
      * Sets the suggested palette information to be stored with this
@@ -951,8 +965,8 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
     // sBIT chunk
 
-    private int[] significantBits = null;
-    private boolean significantBitsSet = false;
+    private int[] significantBits;
+    private boolean significantBitsSet;
 
     /**
      * Sets the number of significant bits for each band of the image.
@@ -1003,8 +1017,8 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
     // sRGB chunk
 
-    private int SRGBIntent;
-    private boolean SRGBIntentSet = false;
+    private int srgbIntent;
+    private boolean srgbIntentSet;
 
     /**
      * Sets the sRGB rendering intent to be stored with this image.
@@ -1014,9 +1028,9 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
      *
      * <p> The 'sRGB' chunk will encode this information.
      */
-    public void setSRGBIntent(int SRGBIntent) {
-        this.SRGBIntent = SRGBIntent;
-        SRGBIntentSet = true;
+    public void setSRGBIntent(int srgbIntent) {
+        this.srgbIntent = srgbIntent;
+        srgbIntentSet = true;
     }
 
     /**
@@ -1028,30 +1042,30 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
      * @throws IllegalStateException if the sRGB intent is not set.
      */
     public int getSRGBIntent() {
-        if (!SRGBIntentSet) {
+        if (!srgbIntentSet) {
             throw new IllegalStateException(PropertyUtil.getString("PNGEncodeParam19"));
         }
-        return SRGBIntent;
+        return srgbIntent;
     }
 
     /**
      * Suppresses the 'sRGB' chunk from being output.
      */
     public void unsetSRGBIntent() {
-        SRGBIntentSet = false;
+        srgbIntentSet = false;
     }
 
     /**
      * Returns true if an 'sRGB' chunk will be output.
      */
     public boolean isSRGBIntentSet() {
-        return SRGBIntentSet;
+        return srgbIntentSet;
     }
 
     // tEXt chunk
 
-    private String[] text = null;
-    private boolean textSet = false;
+    private String[] text;
+    private boolean textSet;
 
     /**
      * Sets the textual data to be stored in uncompressed form with this
@@ -1099,7 +1113,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
     // tIME chunk
 
     private Date modificationTime;
-    private boolean modificationTimeSet = false;
+    private boolean modificationTimeSet;
 
     /**
      * Sets the modification time, as a <code>Date</code>, to be
@@ -1146,7 +1160,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
     // tRNS chunk
 
-    boolean transparencySet = false;
+    boolean transparencySet;
 
     /**
      * Suppresses the 'tRNS' chunk from being output.
@@ -1164,8 +1178,8 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
 
     // zTXT chunk
 
-    private String[] zText = null;
-    private boolean zTextSet = false;
+    private String[] zText;
+    private boolean zTextSet;
 
     /**
      * Sets the text strings to be stored in compressed form with this
@@ -1291,7 +1305,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
     /**
      * An abs() function for use by the Paeth predictor.
      */
-    private static final int abs(int x) {
+    private static int abs(int x) {
         return (x < 0) ? -x : x;
     }
 
@@ -1300,7 +1314,7 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
      * is included as a convenience to subclasses that override the
      * <code>filterRow</code> method.
      */
-    public static final int paethPredictor(int a, int b, int c) {
+    public static int paethPredictor(int a, int b, int c) {
         int p = a + b - c;
         int pa = abs(p - a);
         int pb = abs(p - b);
@@ -1341,9 +1355,9 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
      * could be implemented (non-optimally) as follows:
      *
      * <pre>
-     * for (int i = bytesPerPixel; i < bytesPerRow + bytesPerPixel; i++) {
-     *     int curr = currRow[i] & 0xff;
-     *     int left = currRow[i - bytesPerPixel] & 0xff;
+     * for (int i = bytesPerPixel; i &lt; bytesPerRow + bytesPerPixel; i++) {
+     *     int curr = currRow[i] &amp; 0xff;
+     *     int left = currRow[i - bytesPerPixel] &amp; 0xff;
      *     scratchRow[PNG_FILTER_SUB][i] = (byte)(curr - left);
      * }
      * return PNG_FILTER_SUB;
@@ -1379,8 +1393,14 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
                          int bytesPerPixel) {
 
         int [] badness = {0, 0, 0, 0, 0};
-        int curr, left, up, upleft, diff;
-        int pa, pb, pc;
+        int curr;
+        int left;
+        int up;
+        int upleft;
+        int diff;
+        int pa;
+        int pb;
+        int pc;
         for (int i = bytesPerPixel; i < bytesPerRow + bytesPerPixel; i++) {
             curr   = currRow[i] & 0xff;
             left   = currRow[i - bytesPerPixel] & 0xff;
@@ -1393,17 +1413,17 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
             // sub filter
             diff = curr - left;
             scratchRows[1][i]  = (byte)diff;
-            badness    [1]    +=   (diff>0)?diff:-diff;
+            badness    [1]    +=   (diff > 0) ? diff : -diff;
 
             // up filter
             diff = curr - up;
             scratchRows[2][i]  = (byte)diff;
-            badness    [2]    +=   (diff>=0)?diff:-diff;
+            badness    [2]    +=   (diff >= 0) ? diff : -diff;
 
             // average filter
-            diff = curr - ((left+up)>>1);
+            diff = curr - ((left + up) >> 1);
             scratchRows[3][i]  = (byte)diff;
-            badness    [3]    +=   (diff>=0)?diff:-diff;
+            badness    [3]    +=   (diff >= 0) ? diff : -diff;
 
             // paeth filter
 
@@ -1423,65 +1443,72 @@ public abstract class PNGEncodeParam implements ImageEncodeParam {
             /// else
             ///   diff = curr-upleft;
 
-            pa = up  -upleft;
-            pb = left-upleft;
-            if (pa<0) {
-              if (pb<0) {
+            pa = up  - upleft;
+            pb = left - upleft;
+            if (pa < 0) {
+              if (pb < 0) {
                 // both pa & pb neg so pc is always greater than or
                 // equal to pa or pb;
-                if (pa >= pb) // since pa & pb neg check sense is reversed.
-                  diff = curr-left;
-                else
-                  diff = curr-up;
+                if (pa >= pb) { // since pa & pb neg check sense is reversed.
+                  diff = curr - left;
+                } else {
+                  diff = curr - up;
+                }
               } else {
                 // pa neg pb pos so we must compute pc...
-                pc = pa+pb;
-                pa=-pa;
-                if (pa <= pb)     // pc is positive and less than pb
-                  if (pa <= pc)
-                    diff = curr-left;
-                  else
-                    diff = curr-upleft;
-                else
+                pc = pa + pb;
+                pa = -pa;
+                if (pa <= pb) { // pc is positive and less than pb
+                  if (pa <= pc) {
+                    diff = curr - left;
+                  } else {
+                    diff = curr - upleft;
+                  }
+                } else {
                   // pc is negative and less than or equal to pa,
                   // but since pa is greater than pb this isn't an issue...
-                  if (pb <= -pc)
-                    diff = curr-up;
-                  else
-                    diff = curr-upleft;
+                  if (pb <= -pc) {
+                    diff = curr - up;
+                  } else {
+                    diff = curr - upleft;
+                  }
+                }
               }
             } else {
-              if (pb<0) {
-                pb =-pb; // make it positive...
+              if (pb < 0) {
+                pb = -pb; // make it positive...
                 if (pa <= pb) {
                   // pc would be negative and less than or equal to pb
-                  pc = pb-pa;
-                  if (pa <= pc)
-                    diff = curr-left;
-                  else if (pb == pc)
+                  pc = pb - pa;
+                  if (pa <= pc) {
+                    diff = curr - left;
+                  } else if (pb == pc) {
                     // if pa is zero then pc==pb otherwise
                     // pc must be less than pb.
-                    diff = curr-up;
-                  else
-                    diff = curr-upleft;
+                    diff = curr - up;
+                  } else {
+                    diff = curr - upleft;
+                  }
                 } else {
                   // pc would be positive and less than pa.
-                  pc = pa-pb;
-                  if (pb <= pc)
-                    diff = curr-up;
-                  else
-                    diff = curr-upleft;
+                  pc = pa - pb;
+                  if (pb <= pc) {
+                    diff = curr - up;
+                  } else {
+                    diff = curr - upleft;
+                  }
                 }
               } else {
                 // both pos so pa+pb is always greater than pa/pb
-                if (pa <= pb)
-                  diff = curr-left;
-                else
-                  diff = curr-up;
+                if (pa <= pb) {
+                  diff = curr - left;
+                } else {
+                  diff = curr - up;
+                }
               }
             }
             scratchRows[4][i]  = (byte)diff;
-            badness    [4]    +=   (diff>=0)?diff:-diff;
+            badness    [4]    +=   (diff >= 0) ? diff : -diff;
         }
         int filterType = 0;
         int minBadness = badness[0];
