@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: PNGRed.java 1345683 2012-06-03 14:50:33Z gadams $ */
+/* $Id: PNGRed.java 1681108 2015-05-22 13:26:12Z ssteiner $ */
 
 package org.apache.xmlgraphics.image.codec.png;
 
@@ -45,6 +45,7 @@ import java.util.Date;
 import java.util.GregorianCalendar;
 import java.util.HashMap;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.TimeZone;
 import java.util.zip.Inflater;
@@ -65,7 +66,7 @@ import org.apache.xmlgraphics.image.rendered.CachableRed;
 // CSOFF: WhitespaceAround
 
 /**
- * @version $Id: PNGRed.java 1345683 2012-06-03 14:50:33Z gadams $
+ * @version $Id: PNGRed.java 1681108 2015-05-22 13:26:12Z ssteiner $
  */
 public class PNGRed extends AbstractRed {
 
@@ -73,7 +74,6 @@ public class PNGRed extends AbstractRed {
         int length;
         int type;
         byte[] data;
-        int crc;
 
         String typeString;
 
@@ -81,7 +81,6 @@ public class PNGRed extends AbstractRed {
             this.length = length;
             this.type = type;
             this.data = data;
-            this.crc = crc;
 
             typeString = "";
             typeString += (char)(type >> 24);
@@ -115,19 +114,19 @@ public class PNGRed extends AbstractRed {
         }
 
         public int getInt2(int offset) {
-            return ((data[offset] & 0xff) << 8) |
-                (data[offset + 1] & 0xff);
+            return ((data[offset] & 0xff) << 8)
+                | (data[offset + 1] & 0xff);
         }
 
         public int getInt4(int offset) {
-            return ((data[offset] & 0xff) << 24) |
-                ((data[offset + 1] & 0xff) << 16) |
-                ((data[offset + 2] & 0xff) << 8) |
-                (data[offset + 3] & 0xff);
+            return ((data[offset] & 0xff) << 24)
+                | ((data[offset + 1] & 0xff) << 16)
+                | ((data[offset + 2] & 0xff) << 8)
+                | (data[offset + 3] & 0xff);
         }
 
         public String getString4(int offset) {
-            String s = new String();
+            String s = "";
             s += (char)data[offset];
             s += (char)data[offset + 1];
             s += (char)data[offset + 2];
@@ -189,46 +188,46 @@ public class PNGRed extends AbstractRed {
 
     private int maxOpacity;
 
-    private int[] significantBits = null;
+    private int[] significantBits;
 
     // Parameter information
 
     // If true, the user wants destination alpha where applicable.
-    private boolean suppressAlpha = false;
+    private boolean suppressAlpha;
 
     // If true, perform palette lookup internally
-    private boolean expandPalette = false;
+    private boolean expandPalette;
 
     // If true, output < 8 bit gray images in 8 bit components format
-    private boolean output8BitGray = false;
+    private boolean output8BitGray;
 
     // Create an alpha channel in the destination color model.
-    private boolean outputHasAlphaPalette = false;
+    private boolean outputHasAlphaPalette;
 
     // Perform gamma correction on the image
-    private boolean performGammaCorrection = false;
+    private boolean performGammaCorrection;
 
     // Expand GA to GGGA for compatbility with Java2D
-    private boolean expandGrayAlpha = false;
+    private boolean expandGrayAlpha;
 
     // Produce an instance of PNGEncodeParam
-    private boolean generateEncodeParam = false;
+    private boolean generateEncodeParam;
 
     // PNGDecodeParam controlling decode process
-    private PNGDecodeParam decodeParam = null;
+    private PNGDecodeParam decodeParam;
 
     // PNGEncodeParam to store file details in
-    private PNGEncodeParam encodeParam = null;
+    private PNGEncodeParam encodeParam;
 
     private boolean emitProperties = true;
 
-    private float fileGamma = 45455/100000.0F;
+    private float fileGamma = 45455 / 100000.0F;
 
     private float userExponent = 1.0F;
 
     private float displayExponent = 2.2F;
 
-    private float[] chromaticity = null;
+    private float[] chromaticity;
 
     private int sRGBRenderingIntent = -1;
 
@@ -294,7 +293,7 @@ public class PNGRed extends AbstractRed {
     private int outputBands;
 
     // Number of private chunks
-    private int chunkIndex = 0;
+    private int chunkIndex;
 
     private List textKeys = new ArrayList();
     private List textStrings = new ArrayList();
@@ -309,18 +308,18 @@ public class PNGRed extends AbstractRed {
     private Map<String, Object> properties = new HashMap<String, Object>();
 
 
-    private int[] gammaLut = null;
+    private int[] gammaLut;
 
     private void initGammaLut(int bits) {
-        double exp = (double)userExponent/(fileGamma*displayExponent);
+        double exp = (double)userExponent / (fileGamma * displayExponent);
         int numSamples = 1 << bits;
         int maxOutSample = (bits == 16) ? 65535 : 255;
 
         gammaLut = new int[numSamples];
         for (int i = 0; i < numSamples; i++) {
-            double gbright = (double)i/(numSamples - 1);
+            double gbright = (double)i / (numSamples - 1);
             double gamma = Math.pow(gbright, exp);
-            int igamma = (int)(gamma*maxOutSample + 0.5);
+            int igamma = (int)(gamma * maxOutSample + 0.5);
             if (igamma > maxOutSample) {
                 igamma = maxOutSample;
             }
@@ -339,7 +338,7 @@ public class PNGRed extends AbstractRed {
           (byte)0xcc, (byte)0xdd, (byte)0xee, (byte)0xff }
     };
 
-    private int[] grayLut = null;
+    private int[] grayLut;
 
     private void initGrayLut(int bits) {
         int len = 1 << bits;
@@ -388,90 +387,83 @@ public class PNGRed extends AbstractRed {
             properties.put("file_type", "PNG v. 1.0");
         }
 
-        try {
-            long magic = distream.readLong();
-            if (magic != 0x89504e470d0a1a0aL) {
-                String msg = PropertyUtil.getString("PNGImageDecoder0");
-                throw new RuntimeException(msg);
-            }
-        } catch (Exception e) {
-            e.printStackTrace();
-            String msg = PropertyUtil.getString("PNGImageDecoder1");
+        long magic = distream.readLong();
+        if (magic != 0x89504e470d0a1a0aL) {
+            String msg = PropertyUtil.getString("PNGImageDecoder0");
             throw new RuntimeException(msg);
         }
 
         do {
-            try {
-                PNGChunk chunk;
+            PNGChunk chunk;
 
-                String chunkType = getChunkType(distream);
-                if (chunkType.equals("IHDR")) {
-                    chunk = readChunk(distream);
-                    parse_IHDR_chunk(chunk);
-                } else if (chunkType.equals("PLTE")) {
-                    chunk = readChunk(distream);
-                    parse_PLTE_chunk(chunk);
-                } else if (chunkType.equals("IDAT")) {
-                    chunk = readChunk(distream);
-                    streamVec.add(new ByteArrayInputStream(chunk.getData()));
-                } else if (chunkType.equals("IEND")) {
-                    chunk = readChunk(distream);
+            String chunkType = getChunkType(distream);
+            if (chunkType.equals("IHDR")) {
+                chunk = readChunk(distream);
+                parse_IHDR_chunk(chunk);
+            } else if (chunkType.equals("PLTE")) {
+                chunk = readChunk(distream);
+                parse_PLTE_chunk(chunk);
+            } else if (chunkType.equals("IDAT")) {
+                chunk = readChunk(distream);
+                streamVec.add(new ByteArrayInputStream(chunk.getData()));
+            } else if (chunkType.equals("IEND")) {
+                chunk = readChunk(distream);
+                try {
                     parse_IEND_chunk(chunk);
-                    break; // fall through to the bottom
-                } else if (chunkType.equals("bKGD")) {
-                    chunk = readChunk(distream);
-                    parse_bKGD_chunk(chunk);
-                } else if (chunkType.equals("cHRM")) {
-                    chunk = readChunk(distream);
-                    parse_cHRM_chunk(chunk);
-                } else if (chunkType.equals("gAMA")) {
-                    chunk = readChunk(distream);
-                    parse_gAMA_chunk(chunk);
-                } else if (chunkType.equals("hIST")) {
-                    chunk = readChunk(distream);
-                    parse_hIST_chunk(chunk);
-                } else if (chunkType.equals("iCCP")) {
-                    chunk = readChunk(distream);
-                    parse_iCCP_chunk(chunk);
-                } else if (chunkType.equals("pHYs")) {
-                    chunk = readChunk(distream);
-                    parse_pHYs_chunk(chunk);
-                } else if (chunkType.equals("sBIT")) {
-                    chunk = readChunk(distream);
-                    parse_sBIT_chunk(chunk);
-                } else if (chunkType.equals("sRGB")) {
-                    chunk = readChunk(distream);
-                    parse_sRGB_chunk(chunk);
-                } else if (chunkType.equals("tEXt")) {
-                    chunk = readChunk(distream);
-                    parse_tEXt_chunk(chunk);
-                } else if (chunkType.equals("tIME")) {
-                    chunk = readChunk(distream);
-                    parse_tIME_chunk(chunk);
-                } else if (chunkType.equals("tRNS")) {
-                    chunk = readChunk(distream);
-                    parse_tRNS_chunk(chunk);
-                } else if (chunkType.equals("zTXt")) {
-                    chunk = readChunk(distream);
-                    parse_zTXt_chunk(chunk);
-                } else {
-                    chunk = readChunk(distream);
-                    // Output the chunk data in raw form
+                } catch (Exception e) {
+                    e.printStackTrace();
+                    String msg = PropertyUtil.getString("PNGImageDecoder2");
+                    throw new RuntimeException(msg);
+                }
+                break; // fall through to the bottom
+            } else if (chunkType.equals("bKGD")) {
+                chunk = readChunk(distream);
+                parse_bKGD_chunk(chunk);
+            } else if (chunkType.equals("cHRM")) {
+                chunk = readChunk(distream);
+                parse_cHRM_chunk(chunk);
+            } else if (chunkType.equals("gAMA")) {
+                chunk = readChunk(distream);
+                parse_gAMA_chunk(chunk);
+            } else if (chunkType.equals("hIST")) {
+                chunk = readChunk(distream);
+                parse_hIST_chunk(chunk);
+            } else if (chunkType.equals("iCCP")) {
+                chunk = readChunk(distream);
+            } else if (chunkType.equals("pHYs")) {
+                chunk = readChunk(distream);
+                parse_pHYs_chunk(chunk);
+            } else if (chunkType.equals("sBIT")) {
+                chunk = readChunk(distream);
+                parse_sBIT_chunk(chunk);
+            } else if (chunkType.equals("sRGB")) {
+                chunk = readChunk(distream);
+                parse_sRGB_chunk(chunk);
+            } else if (chunkType.equals("tEXt")) {
+                chunk = readChunk(distream);
+                parse_tEXt_chunk(chunk);
+            } else if (chunkType.equals("tIME")) {
+                chunk = readChunk(distream);
+                parse_tIME_chunk(chunk);
+            } else if (chunkType.equals("tRNS")) {
+                chunk = readChunk(distream);
+                parse_tRNS_chunk(chunk);
+            } else if (chunkType.equals("zTXt")) {
+                chunk = readChunk(distream);
+                parse_zTXt_chunk(chunk);
+            } else {
+                chunk = readChunk(distream);
+                // Output the chunk data in raw form
 
-                    String type = chunk.getTypeString();
-                    byte[] data = chunk.getData();
-                    if (encodeParam != null) {
-                        encodeParam.addPrivateChunk(type, data);
-                    }
-                    if (emitProperties) {
-                        String key = "chunk_" + chunkIndex++ + ':' + type;
-                        properties.put(key.toLowerCase(), data);
-                    }
+                String type = chunk.getTypeString();
+                byte[] data = chunk.getData();
+                if (encodeParam != null) {
+                    encodeParam.addPrivateChunk(type, data);
+                }
+                if (emitProperties) {
+                    String key = "chunk_" + chunkIndex++ + ':' + type;
+                    properties.put(key.toLowerCase(Locale.getDefault()), data);
                 }
-            } catch (Exception e) {
-                e.printStackTrace();
-                String msg = PropertyUtil.getString("PNGImageDecoder2");
-                throw new RuntimeException(msg);
             }
         } while (true);
 
@@ -502,7 +494,7 @@ public class PNGRed extends AbstractRed {
                               + (char)((type >> 24) & 0xff)
                               + (char)((type >> 16) & 0xff)
                               + (char)((type >>  8) & 0xff)
-                              + (char)( type        & 0xff);
+                              + (char)(type        & 0xff);
             return typeString;
         } catch (Exception e) {
             e.printStackTrace();
@@ -542,11 +534,11 @@ public class PNGRed extends AbstractRed {
         maxOpacity = (1 << bitDepth) - 1;
 
         colorType = chunk.getInt1(9);
-        if ((colorType != PNG_COLOR_GRAY) &&
-            (colorType != PNG_COLOR_RGB) &&
-            (colorType != PNG_COLOR_PALETTE) &&
-            (colorType != PNG_COLOR_GRAY_ALPHA) &&
-            (colorType != PNG_COLOR_RGB_ALPHA)) {
+        if ((colorType != PNG_COLOR_GRAY)
+            && (colorType != PNG_COLOR_RGB)
+            && (colorType != PNG_COLOR_PALETTE)
+            && (colorType != PNG_COLOR_GRAY_ALPHA)
+            && (colorType != PNG_COLOR_RGB_ALPHA)) {
             System.out.println(PropertyUtil.getString("PNGImageDecoder4"));
         }
 
@@ -581,8 +573,8 @@ public class PNGRed extends AbstractRed {
         if (generateEncodeParam) {
             if (colorType == PNG_COLOR_PALETTE) {
                 encodeParam = new PNGEncodeParam.Palette();
-            } else if (colorType == PNG_COLOR_GRAY ||
-                       colorType == PNG_COLOR_GRAY_ALPHA) {
+            } else if (colorType == PNG_COLOR_GRAY
+                       || colorType == PNG_COLOR_GRAY_ALPHA) {
                 encodeParam = new PNGEncodeParam.Gray();
             } else {
                 encodeParam = new PNGEncodeParam.RGB();
@@ -594,17 +586,17 @@ public class PNGRed extends AbstractRed {
             encodeParam.setBitDepth(bitDepth);
         }
         if (emitProperties) {
-            properties.put("bit_depth", new Integer(bitDepth));
+            properties.put("bit_depth", bitDepth);
         }
 
         if (performGammaCorrection) {
             // Assume file gamma is 1/2.2 unless we get a gAMA chunk
-            float gamma = (1.0F/2.2F)*(displayExponent/userExponent);
+            float gamma = (1.0F / 2.2F) * (displayExponent / userExponent);
             if (encodeParam != null) {
                 encodeParam.setGamma(gamma);
             }
             if (emitProperties) {
-                properties.put("gamma", new Float(gamma));
+                properties.put("gamma", gamma);
             }
         }
 
@@ -724,15 +716,15 @@ public class PNGRed extends AbstractRed {
     private void parse_IEND_chunk(PNGChunk chunk) throws Exception {
         // Store text strings
         int textLen = textKeys.size();
-        String[] textArray = new String[2*textLen];
+        String[] textArray = new String[2 * textLen];
         for (int i = 0; i < textLen; i++) {
             String key = (String)textKeys.get(i);
             String val = (String)textStrings.get(i);
-            textArray[2*i] = key;
-            textArray[2*i + 1] = val;
+            textArray[2 * i] = key;
+            textArray[2 * i + 1] = val;
             if (emitProperties) {
                 String uniqueKey = "text_" + i + ':' + key;
-                properties.put(uniqueKey.toLowerCase(), val);
+                properties.put(uniqueKey.toLowerCase(Locale.getDefault()), val);
             }
         }
         if (encodeParam != null) {
@@ -741,15 +733,15 @@ public class PNGRed extends AbstractRed {
 
         // Store compressed text strings
         int ztextLen = ztextKeys.size();
-        String[] ztextArray = new String[2*ztextLen];
+        String[] ztextArray = new String[2 * ztextLen];
         for (int i = 0; i < ztextLen; i++) {
             String key = (String)ztextKeys.get(i);
             String val = (String)ztextStrings.get(i);
-            ztextArray[2*i] = key;
-            ztextArray[2*i + 1] = val;
+            ztextArray[2 * i] = key;
+            ztextArray[2 * i + 1] = val;
             if (emitProperties) {
                 String uniqueKey = "ztext_" + i + ':' + key;
-                properties.put(uniqueKey.toLowerCase(), val);
+                properties.put(uniqueKey.toLowerCase(Locale.getDefault()), val);
             }
         }
         if (encodeParam != null) {
@@ -758,15 +750,15 @@ public class PNGRed extends AbstractRed {
 
         // Parse prior IDAT chunks
         InputStream seqStream =
-            new SequenceInputStream( Collections.enumeration( streamVec ));
+            new SequenceInputStream(Collections.enumeration(streamVec));
         InputStream infStream =
             new InflaterInputStream(seqStream, new Inflater());
         dataStream = new DataInputStream(infStream);
 
         // Create an empty WritableRaster
         int depth = bitDepth;
-        if ((colorType == PNG_COLOR_GRAY) &&
-            (bitDepth < 8) && output8BitGray) {
+        if ((colorType == PNG_COLOR_GRAY)
+            && (bitDepth < 8) && output8BitGray) {
             depth = 8;
         }
         if ((colorType == PNG_COLOR_PALETTE) && expandPalette) {
@@ -775,9 +767,9 @@ public class PNGRed extends AbstractRed {
         int width  = bounds.width;
         int height = bounds.height;
 
-        int bytesPerRow = (outputBands*width*depth + 7)/8;
+        int bytesPerRow = (outputBands * width * depth + 7) / 8;
         int scanlineStride =
-            (depth == 16) ? (bytesPerRow/2) : bytesPerRow;
+            (depth == 16) ? (bytesPerRow / 2) : bytesPerRow;
 
         theTile = createRaster(width, height, outputBands,
                                scanlineStride,
@@ -786,9 +778,9 @@ public class PNGRed extends AbstractRed {
         if (performGammaCorrection && (gammaLut == null)) {
             initGammaLut(bitDepth);
         }
-        if ((postProcess == POST_GRAY_LUT) ||
-            (postProcess == POST_GRAY_LUT_ADD_TRANS) ||
-            (postProcess == POST_GRAY_LUT_ADD_TRANS_EXP)) {
+        if ((postProcess == POST_GRAY_LUT)
+            || (postProcess == POST_GRAY_LUT_ADD_TRANS)
+            || (postProcess == POST_GRAY_LUT_ADD_TRANS_EXP)) {
             initGrayLut(bitDepth);
         }
 
@@ -818,8 +810,8 @@ public class PNGRed extends AbstractRed {
                                                  greenPalette,
                                                  bluePalette);
             }
-        } else if ((colorType == PNG_COLOR_GRAY) &&
-                   (bitDepth < 8) && !output8BitGray) {
+        } else if ((colorType == PNG_COLOR_GRAY)
+                   && (bitDepth < 8) && !output8BitGray) {
             byte[] palette = expandBits[bitDepth];
             cm = new IndexColorModel(bitDepth,
                                              palette.length,
@@ -983,7 +975,7 @@ public class PNGRed extends AbstractRed {
     }
 
     private void parse_PLTE_chunk(PNGChunk chunk) {
-        paletteEntries = chunk.getLength()/3;
+        paletteEntries = chunk.getLength() / 3;
         redPalette = new byte[paletteEntries];
         greenPalette = new byte[paletteEntries];
         bluePalette = new byte[paletteEntries];
@@ -1024,8 +1016,7 @@ public class PNGRed extends AbstractRed {
             bkgdBlue  = bluePalette[bkgdIndex]  & 0xff;
 
             if (encodeParam != null) {
-                ((PNGEncodeParam.Palette)encodeParam).
-                    setBackgroundPaletteIndex(bkgdIndex);
+                ((PNGEncodeParam.Palette)encodeParam).setBackgroundPaletteIndex(bkgdIndex);
             }
             break;
         case PNG_COLOR_GRAY: case PNG_COLOR_GRAY_ALPHA:
@@ -1033,8 +1024,7 @@ public class PNGRed extends AbstractRed {
             bkgdRed = bkgdGreen = bkgdBlue = bkgdGray;
 
             if (encodeParam != null) {
-                ((PNGEncodeParam.Gray)encodeParam).
-                    setBackgroundGray(bkgdGray);
+                ((PNGEncodeParam.Gray)encodeParam).setBackgroundGray(bkgdGray);
             }
             break;
         case PNG_COLOR_RGB: case PNG_COLOR_RGB_ALPHA:
@@ -1047,14 +1037,15 @@ public class PNGRed extends AbstractRed {
             bkgdRGB[1] = bkgdGreen;
             bkgdRGB[2] = bkgdBlue;
             if (encodeParam != null) {
-                ((PNGEncodeParam.RGB)encodeParam).
-                    setBackgroundRGB(bkgdRGB);
+                ((PNGEncodeParam.RGB)encodeParam).setBackgroundRGB(bkgdRGB);
             }
             break;
         }
 
         if (emitProperties) {
-            int r = 0, g = 0, b = 0;
+            int r = 0;
+            int g = 0;
+            int b = 0;
             if ((colorType == PNG_COLOR_PALETTE) || (bitDepth == 8)) {
                 r = bkgdRed;
                 g = bkgdGreen;
@@ -1079,27 +1070,27 @@ public class PNGRed extends AbstractRed {
         }
 
         chromaticity = new float[8];
-        chromaticity[0] = chunk.getInt4(0)/100000.0F;
-        chromaticity[1] = chunk.getInt4(4)/100000.0F;
-        chromaticity[2] = chunk.getInt4(8)/100000.0F;
-        chromaticity[3] = chunk.getInt4(12)/100000.0F;
-        chromaticity[4] = chunk.getInt4(16)/100000.0F;
-        chromaticity[5] = chunk.getInt4(20)/100000.0F;
-        chromaticity[6] = chunk.getInt4(24)/100000.0F;
-        chromaticity[7] = chunk.getInt4(28)/100000.0F;
+        chromaticity[0] = chunk.getInt4(0) / 100000.0F;
+        chromaticity[1] = chunk.getInt4(4) / 100000.0F;
+        chromaticity[2] = chunk.getInt4(8) / 100000.0F;
+        chromaticity[3] = chunk.getInt4(12) / 100000.0F;
+        chromaticity[4] = chunk.getInt4(16) / 100000.0F;
+        chromaticity[5] = chunk.getInt4(20) / 100000.0F;
+        chromaticity[6] = chunk.getInt4(24) / 100000.0F;
+        chromaticity[7] = chunk.getInt4(28) / 100000.0F;
 
         if (encodeParam != null) {
             encodeParam.setChromaticity(chromaticity);
         }
         if (emitProperties) {
-            properties.put("white_point_x", new Float(chromaticity[0]));
-            properties.put("white_point_y", new Float(chromaticity[1]));
-            properties.put("red_x", new Float(chromaticity[2]));
-            properties.put("red_y", new Float(chromaticity[3]));
-            properties.put("green_x", new Float(chromaticity[4]));
-            properties.put("green_y", new Float(chromaticity[5]));
-            properties.put("blue_x", new Float(chromaticity[6]));
-            properties.put("blue_y", new Float(chromaticity[7]));
+            properties.put("white_point_x", chromaticity[0]);
+            properties.put("white_point_y", chromaticity[1]);
+            properties.put("red_x", chromaticity[2]);
+            properties.put("red_y", chromaticity[3]);
+            properties.put("green_x", chromaticity[4]);
+            properties.put("green_y", chromaticity[5]);
+            properties.put("blue_x", chromaticity[6]);
+            properties.put("blue_y", chromaticity[7]);
         }
     }
 
@@ -1109,15 +1100,15 @@ public class PNGRed extends AbstractRed {
             return;
         }
 
-        fileGamma = chunk.getInt4(0)/100000.0F;
+        fileGamma = chunk.getInt4(0) / 100000.0F;
         // System.out.println("Gamma: " + fileGamma);
         float exp =
-            performGammaCorrection ? displayExponent/userExponent : 1.0F;
+            performGammaCorrection ? displayExponent / userExponent : 1.0F;
         if (encodeParam != null) {
-            encodeParam.setGamma(fileGamma*exp);
+            encodeParam.setGamma(fileGamma * exp);
         }
         if (emitProperties) {
-            properties.put("gamma", new Float(fileGamma*exp));
+            properties.put("gamma", fileGamma * exp);
         }
     }
 
@@ -1130,7 +1121,7 @@ public class PNGRed extends AbstractRed {
         int length = redPalette.length;
         int[] hist = new int[length];
         for (int i = 0; i < length; i++) {
-            hist[i] = chunk.getInt2(2*i);
+            hist[i] = chunk.getInt2(2 * i);
         }
 
         if (encodeParam != null) {
@@ -1138,16 +1129,6 @@ public class PNGRed extends AbstractRed {
         }
     }
 
-    private void parse_iCCP_chunk(PNGChunk chunk) {
-        String name = "";
-        byte b;
-
-        int textIndex = 0;
-        while ((b = chunk.getByte(textIndex++)) != 0) {
-            name += (char)b;
-        }
-    }
-
     private void parse_pHYs_chunk(PNGChunk chunk) {
         int xPixelsPerUnit = chunk.getInt4(0);
         int yPixelsPerUnit = chunk.getInt4(4);
@@ -1159,10 +1140,10 @@ public class PNGRed extends AbstractRed {
                                              unitSpecifier);
         }
         if (emitProperties) {
-            properties.put("x_pixels_per_unit", new Integer(xPixelsPerUnit));
-            properties.put("y_pixels_per_unit", new Integer(yPixelsPerUnit));
+            properties.put("x_pixels_per_unit", xPixelsPerUnit);
+            properties.put("y_pixels_per_unit", yPixelsPerUnit);
             properties.put("pixel_aspect_ratio",
-                           new Float((float)xPixelsPerUnit/yPixelsPerUnit));
+                    (float) xPixelsPerUnit / yPixelsPerUnit);
             if (unitSpecifier == 1) {
                 properties.put("pixel_units", "Meters");
             } else if (unitSpecifier != 0) {
@@ -1204,35 +1185,35 @@ public class PNGRed extends AbstractRed {
 
         // The presence of an sRGB chunk implies particular
         // settings for gamma and chroma.
-        fileGamma = 45455/100000.0F;
+        fileGamma = 45455 / 100000.0F;
 
         chromaticity = new float[8];
-        chromaticity[0] = 31270/10000.0F;
-        chromaticity[1] = 32900/10000.0F;
-        chromaticity[2] = 64000/10000.0F;
-        chromaticity[3] = 33000/10000.0F;
-        chromaticity[4] = 30000/10000.0F;
-        chromaticity[5] = 60000/10000.0F;
-        chromaticity[6] = 15000/10000.0F;
-        chromaticity[7] =  6000/10000.0F;
+        chromaticity[0] = 31270 / 10000.0F;
+        chromaticity[1] = 32900 / 10000.0F;
+        chromaticity[2] = 64000 / 10000.0F;
+        chromaticity[3] = 33000 / 10000.0F;
+        chromaticity[4] = 30000 / 10000.0F;
+        chromaticity[5] = 60000 / 10000.0F;
+        chromaticity[6] = 15000 / 10000.0F;
+        chromaticity[7] =  6000 / 10000.0F;
 
         if (performGammaCorrection) {
             // File gamma is 1/2.2
-            float gamma = fileGamma*(displayExponent/userExponent);
+            float gamma = fileGamma * (displayExponent / userExponent);
             if (encodeParam != null) {
                 encodeParam.setGamma(gamma);
                 encodeParam.setChromaticity(chromaticity);
             }
             if (emitProperties) {
-                properties.put("gamma", new Float(gamma));
-                properties.put("white_point_x", new Float(chromaticity[0]));
-                properties.put("white_point_y", new Float(chromaticity[1]));
-                properties.put("red_x", new Float(chromaticity[2]));
-                properties.put("red_y", new Float(chromaticity[3]));
-                properties.put("green_x", new Float(chromaticity[4]));
-                properties.put("green_y", new Float(chromaticity[5]));
-                properties.put("blue_x", new Float(chromaticity[6]));
-                properties.put("blue_y", new Float(chromaticity[7]));
+                properties.put("gamma", gamma);
+                properties.put("white_point_x", chromaticity[0]);
+                properties.put("white_point_y", chromaticity[1]);
+                properties.put("red_x", chromaticity[2]);
+                properties.put("red_y", chromaticity[3]);
+                properties.put("green_x", chromaticity[4]);
+                properties.put("green_y", chromaticity[5]);
+                properties.put("blue_x", chromaticity[6]);
+                properties.put("blue_y", chromaticity[7]);
             }
         }
     }
@@ -1326,8 +1307,7 @@ public class PNGRed extends AbstractRed {
                 }
 
                 if (encodeParam != null) {
-                    ((PNGEncodeParam.Gray)encodeParam).
-                        setTransparentGray(grayTransparentAlpha);
+                    ((PNGEncodeParam.Gray)encodeParam).setTransparentGray(grayTransparentAlpha);
                 }
             }
         } else if (colorType == PNG_COLOR_RGB) {
@@ -1344,12 +1324,11 @@ public class PNGRed extends AbstractRed {
                     rgbTrans[0] = redTransparentAlpha;
                     rgbTrans[1] = greenTransparentAlpha;
                     rgbTrans[2] = blueTransparentAlpha;
-                    ((PNGEncodeParam.RGB)encodeParam).
-                        setTransparentRGB(rgbTrans);
+                    ((PNGEncodeParam.RGB)encodeParam).setTransparentRGB(rgbTrans);
                 }
             }
-        } else if (colorType == PNG_COLOR_GRAY_ALPHA ||
-                   colorType == PNG_COLOR_RGB_ALPHA) {
+        } else if (colorType == PNG_COLOR_GRAY_ALPHA
+                   || colorType == PNG_COLOR_RGB_ALPHA) {
             // Error -- GA or RGBA image can't have a tRNS chunk.
             String msg = PropertyUtil.getString("PNGImageDecoder15");
             throw new RuntimeException(msg);
@@ -1379,8 +1358,8 @@ public class PNGRed extends AbstractRed {
                 value.append((char)c);
             }
 
-            ztextKeys.add(key.toString() );
-            ztextStrings.add(value.toString() );
+            ztextKeys.add(key.toString());
+            ztextStrings.add(value.toString());
         } catch (Exception e) {
             e.printStackTrace();
         }
@@ -1394,13 +1373,13 @@ public class PNGRed extends AbstractRed {
         WritableRaster ras = null;
         Point origin = new Point(0, 0);
         if ((bitDepth < 8) && (bands == 1)) {
-            dataBuffer = new DataBufferByte(height*scanlineStride);
+            dataBuffer = new DataBufferByte(height * scanlineStride);
             ras = Raster.createPackedRaster(dataBuffer,
                                             width, height,
                                             bitDepth,
                                             origin);
         } else if (bitDepth <= 8) {
-            dataBuffer = new DataBufferByte(height*scanlineStride);
+            dataBuffer = new DataBufferByte(height * scanlineStride);
            ras = Raster.createInterleavedRaster(dataBuffer,
                                                  width, height,
                                                  scanlineStride,
@@ -1408,7 +1387,7 @@ public class PNGRed extends AbstractRed {
                                                  bandOffsets[bands],
                                                  origin);
         } else {
-            dataBuffer = new DataBufferUShort(height*scanlineStride);
+            dataBuffer = new DataBufferUShort(height * scanlineStride);
             ras = Raster.createInterleavedRaster(dataBuffer,
                                                  width, height,
                                                  scanlineStride,
@@ -1449,7 +1428,7 @@ public class PNGRed extends AbstractRed {
             int raw      = curr[i] & 0xff;
             int priorRow = prev[i] & 0xff;
 
-            curr[i] = (byte)(raw + priorRow/2);
+            curr[i] = (byte)(raw + priorRow / 2);
         }
 
         for (int i = bpp; i < count; i++) {
@@ -1457,7 +1436,7 @@ public class PNGRed extends AbstractRed {
             int priorPixel = curr[i - bpp] & 0xff;
             int priorRow = prev[i] & 0xff;
 
-            curr[i] = (byte)(raw + (priorPixel + priorRow)/2);
+            curr[i] = (byte)(raw + (priorPixel + priorRow) / 2);
         }
     }
 
@@ -1478,7 +1457,8 @@ public class PNGRed extends AbstractRed {
 
     private static void decodePaethFilter(byte[] curr, byte[] prev,
                                           int count, int bpp) {
-        int priorPixel, priorRowPixel;
+        int priorPixel;
+        int priorRowPixel;
 
         for (int i = 0; i < bpp; i++) {
             int raw = curr[i] & 0xff;
@@ -1502,7 +1482,8 @@ public class PNGRed extends AbstractRed {
     private void processPixels(int process,
                                Raster src, WritableRaster dst,
                                int xOffset, int step, int y, int width) {
-        int srcX, dstX;
+        int srcX;
+        int dstX;
 
         // Create an array suitable for holding one pixel
         int[] ps = src.getPixel(0, 0, (int[])null);
@@ -1627,9 +1608,9 @@ public class PNGRed extends AbstractRed {
                     pd[1] = g;
                     pd[2] = b;
                 }
-                if ((r == redTransparentAlpha) &&
-                    (g == greenTransparentAlpha) &&
-                    (b == blueTransparentAlpha)) {
+                if ((r == redTransparentAlpha)
+                    && (g == greenTransparentAlpha)
+                    && (b == blueTransparentAlpha)) {
                     pd[3] = 0;
                 } else {
                     pd[3] = maxOpacity;
@@ -1767,8 +1748,8 @@ public class PNGRed extends AbstractRed {
             return;
         }
 
-        int bytesPerRow = (inputBands*passWidth*bitDepth + 7)/8;
-        int eltsPerRow = (bitDepth == 16) ? bytesPerRow/2 : bytesPerRow;
+        int bytesPerRow = (inputBands * passWidth * bitDepth + 7) / 8;
+        int eltsPerRow = (bitDepth == 16) ? bytesPerRow / 2 : bytesPerRow;
         byte[] curr = new byte[bytesPerRow];
         byte[] prior = new byte[bytesPerRow];
 
@@ -1788,7 +1769,8 @@ public class PNGRed extends AbstractRed {
         }
 
         // Decode the (sub)image row-by-row
-        int srcY, dstY;
+        int srcY;
+        int dstY;
         for (srcY = 0, dstY = yOffset;
              srcY < passHeight;
              srcY++, dstY += yStep) {
@@ -1851,13 +1833,13 @@ public class PNGRed extends AbstractRed {
         if (!useInterlacing) {
             decodePass(theTile, 0, 0, 1, 1, width, height);
         } else {
-            decodePass(theTile, 0, 0, 8, 8, (width + 7)/8, (height + 7)/8);
-            decodePass(theTile, 4, 0, 8, 8, (width + 3)/8, (height + 7)/8);
-            decodePass(theTile, 0, 4, 4, 8, (width + 3)/4, (height + 3)/8);
-            decodePass(theTile, 2, 0, 4, 4, (width + 1)/4, (height + 3)/4);
-            decodePass(theTile, 0, 2, 2, 4, (width + 1)/2, (height + 1)/4);
-            decodePass(theTile, 1, 0, 2, 2, width/2, (height + 1)/2);
-            decodePass(theTile, 0, 1, 1, 2, width, height/2);
+            decodePass(theTile, 0, 0, 8, 8, (width + 7) / 8, (height + 7) / 8);
+            decodePass(theTile, 4, 0, 8, 8, (width + 3) / 8, (height + 7) / 8);
+            decodePass(theTile, 0, 4, 4, 8, (width + 3) / 4, (height + 3) / 8);
+            decodePass(theTile, 2, 0, 4, 4, (width + 1) / 4, (height + 3) / 4);
+            decodePass(theTile, 0, 2, 2, 4, (width + 1) / 2, (height + 1) / 4);
+            decodePass(theTile, 1, 0, 2, 2, width / 2, (height + 1) / 2);
+            decodePass(theTile, 0, 1, 1, 2, width, height / 2);
         }
     }
 
