@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: PropertyUtil.java 1345683 2012-06-03 14:50:33Z gadams $ */
+/* $Id: PropertyUtil.java 1681108 2015-05-22 13:26:12Z ssteiner $ */
 
 package org.apache.xmlgraphics.image.codec.util;
 
@@ -28,17 +28,17 @@ public final class PropertyUtil {
     private PropertyUtil() {
     }
 
-    protected static final String RESOURCES =
+    private static final String RESOURCES =
         "org.apache.xmlgraphics.image.codec.Messages";
 
 
-    protected static LocalizableSupport localizableSupport =
-        new LocalizableSupport
-        (RESOURCES, PropertyUtil.class.getClassLoader());
+    private static final LocalizableSupport LOCALIZABLESUPPORT =
+        new LocalizableSupport(
+        RESOURCES, PropertyUtil.class.getClassLoader());
 
     public static String getString(String key) {
         try {
-            return localizableSupport.formatMessage(key, null);
+            return LOCALIZABLESUPPORT.formatMessage(key, null);
         } catch (MissingResourceException e) {
             return key;
         }
