@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,11 +15,13 @@
  * limitations under the License.
  */
 
-/* $Id: AbstractImageLoaderFactory.java 606580 2007-12-23 17:45:02Z jeremias $ */
+/* $Id: AbstractImageLoaderFactory.java 924666 2010-03-18 08:26:30Z jeremias $ */
 
 package org.apache.xmlgraphics.image.loader.impl;
 
+import org.apache.xmlgraphics.image.loader.ImageFlavor;
 import org.apache.xmlgraphics.image.loader.ImageInfo;
+import org.apache.xmlgraphics.image.loader.spi.ImageLoader;
 import org.apache.xmlgraphics.image.loader.spi.ImageLoaderFactory;
 
 /**
@@ -34,4 +36,14 @@ public abstract class AbstractImageLoaderFactory implements ImageLoaderFactory {
         return true;
     }
 
+    /**
+     * {@inheritDoc}
+     * @deprecated Redundancy with {@link ImageLoader#getUsagePenalty()}
+     */
+    public int getUsagePenalty(String mime, ImageFlavor flavor) {
+        //Kept for compatibility
+        ImageLoader loader = newImageLoader(flavor);
+        return loader.getUsagePenalty();
+    }
+
 }
