@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: CompositeImageLoader.java 924666 2010-03-18 08:26:30Z jeremias $ */
+/* $Id: CompositeImageLoader.java 1681137 2015-05-22 14:54:05Z ssteiner $ */
 
 package org.apache.xmlgraphics.image.loader.impl;
 
@@ -39,7 +39,7 @@ import org.apache.xmlgraphics.image.loader.spi.ImageLoader;
 public class CompositeImageLoader extends AbstractImageLoader {
 
     /** logger */
-    protected static Log log = LogFactory.getLog(CompositeImageLoader.class);
+    protected static final Log log = LogFactory.getLog(CompositeImageLoader.class);
 
     private ImageLoader[] loaders;
 
