@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: ImageImplRegistry.java 924666 2010-03-18 08:26:30Z jeremias $ */
+/* $Id: ImageImplRegistry.java 1681108 2015-05-22 13:26:12Z ssteiner $ */
 
 package org.apache.xmlgraphics.image.loader.spi;
 
@@ -42,7 +42,7 @@ import org.apache.xmlgraphics.util.Service;
 public class ImageImplRegistry {
 
     /** logger */
-    protected static Log log = LogFactory.getLog(ImageImplRegistry.class);
+    protected static final Log log = LogFactory.getLog(ImageImplRegistry.class);
 
     /** Infinite penalty value which shall force any implementation to become ineligible. */
     public static final int INFINITE_PENALTY = Integer.MAX_VALUE;
@@ -68,7 +68,7 @@ public class ImageImplRegistry {
     //Note: String as key chosen to avoid possible class-unloading leaks
 
     /** Singleton instance */
-    private static ImageImplRegistry defaultInstance;
+    private static ImageImplRegistry defaultInstance = new ImageImplRegistry();
 
     /**
      * Main constructor. This constructor allows to disable plug-in discovery for testing purposes.
@@ -82,7 +82,6 @@ public class ImageImplRegistry {
 
     /**
      * Main constructor.
-     * @see #getDefaultInstance()
      */
     public ImageImplRegistry() {
         this(true);
@@ -93,9 +92,6 @@ public class ImageImplRegistry {
      * @return the default instance
      */
     public static ImageImplRegistry getDefaultInstance() {
-        if (defaultInstance == null) {
-            defaultInstance = new ImageImplRegistry();
-        }
         return defaultInstance;
     }
 
@@ -104,19 +100,19 @@ public class ImageImplRegistry {
      */
     public void discoverClasspathImplementations() {
         //Dynamic registration of ImagePreloaders
-        Iterator iter = Service.providers(ImagePreloader.class, true);
+        Iterator iter = Service.providers(ImagePreloader.class);
         while (iter.hasNext()) {
             registerPreloader((ImagePreloader)iter.next());
         }
 
         //Dynamic registration of ImageLoaderFactories
-        iter = Service.providers(ImageLoaderFactory.class, true);
+        iter = Service.providers(ImageLoaderFactory.class);
         while (iter.hasNext()) {
             registerLoaderFactory((ImageLoaderFactory)iter.next());
         }
 
         //Dynamic registration of ImageConverters
-        iter = Service.providers(ImageConverter.class, true);
+        iter = Service.providers(ImageConverter.class);
         while (iter.hasNext()) {
             registerConverter((ImageConverter)iter.next());
         }
@@ -223,7 +219,7 @@ public class ImageImplRegistry {
 
     /**
      * Returns the Collection of registered ImageConverter instances.
-     * @return a Collection<ImageConverter>
+     * @return a Collection&lt;ImageConverter&gt;
      */
     public Collection getImageConverters() {
         return Collections.unmodifiableList(this.converters);
@@ -258,26 +254,30 @@ public class ImageImplRegistry {
         sortPreloaders();
         final Iterator iter = this.preloaders.iterator();
         //Unpack the holders
-        return new Iterator() {
+        MyIterator i = new MyIterator();
+        i.iter = iter;
+        return i;
+    }
 
-            public boolean hasNext() {
-                return iter.hasNext();
+    static class MyIterator implements Iterator {
+        Iterator iter;
+        public boolean hasNext() {
+            return iter.hasNext();
+        }
+
+        public Object next() {
+            Object obj = iter.next();
+            if (obj != null) {
+                return ((PreloaderHolder)obj).preloader;
+            } else {
+                return null;
             }
+        }
 
-            public Object next() {
-                Object obj = iter.next();
-                if (obj != null) {
-                    return ((PreloaderHolder)obj).preloader;
-                } else {
-                    return null;
-                }
-            }
+        public void remove() {
+            iter.remove();
+        }
 
-            public void remove() {
-                iter.remove();
-            }
-
-        };
     }
 
     /**
@@ -324,13 +324,13 @@ public class ImageImplRegistry {
     public ImageLoaderFactory[] getImageLoaderFactories(ImageInfo imageInfo, ImageFlavor flavor) {
         String mime = imageInfo.getMimeType();
         Collection matches = new java.util.TreeSet(new ImageLoaderFactoryComparator(flavor));
-        Map flavorMap = (Map)loaders.get(mime);
+        Map flavorMap = (Map) loaders.get(mime);
         if (flavorMap != null) {
-            Iterator flavorIter = flavorMap.keySet().iterator();
-            while (flavorIter.hasNext()) {
-                ImageFlavor checkFlavor = (ImageFlavor)flavorIter.next();
+            for (Object i : flavorMap.entrySet()) {
+                Map.Entry e = (Map.Entry) i;
+                ImageFlavor checkFlavor = (ImageFlavor) e.getKey();
                 if (checkFlavor.isCompatible(flavor)) {
-                    List factoryList = (List)flavorMap.get(checkFlavor);
+                    List factoryList = (List)e.getValue();
                     if (factoryList != null && factoryList.size() > 0) {
                         Iterator factoryIter = factoryList.iterator();
                         while (factoryIter.hasNext()) {
@@ -367,8 +367,8 @@ public class ImageImplRegistry {
 
             ImageLoaderFactory f2 = (ImageLoaderFactory)o2;
             ImageLoader l2 = f2.newImageLoader(targetFlavor);
-            long p2 = l2.getUsagePenalty();
-            p2 = getAdditionalPenalty(l2.getClass().getName()).getValue();
+//            long p2 = l2.getUsagePenalty();
+            long p2 = getAdditionalPenalty(l2.getClass().getName()).getValue();
 
             //Lowest penalty first
             return Penalty.truncate(p1 - p2);
@@ -398,7 +398,7 @@ public class ImageImplRegistry {
                         new ImageLoaderFactory[factoryCount]);
             }
         }
-        return null;
+        return new ImageLoaderFactory[0];
     }
 
     /**
