@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: AbstractRed.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: AbstractRed.java 1681108 2015-05-22 13:26:12Z ssteiner $ */
 
 package org.apache.xmlgraphics.image.rendered;
 
@@ -40,14 +40,21 @@ import java.util.Vector;
 
 import org.apache.xmlgraphics.image.GraphicsUtil;
 
+// CSOFF: LocalVariableName
+// CSOFF: MultipleVariableDeclarations
+// CSOFF: NeedBraces
+// CSOFF: NoWhitespaceAfter
+// CSOFF: WhitespaceAround
+
 /**
  * This is an abstract base class that takes care of most of the
  * normal issues surrounding the implementation of the CachableRed
  * (RenderedImage) interface.  It tries to make no assumptions about
  * the subclass implementation.
  *
- * @author <a href="mailto:Thomas.DeWeeese@Kodak.com">Thomas DeWeese</a>
- * @version $Id: AbstractRed.java 750418 2009-03-05 11:03:54Z vhennebert $
+ * @version $Id: AbstractRed.java 1681108 2015-05-22 13:26:12Z ssteiner $
+ *
+ * Originally authored by Thomas DeWeese.
  */
 public abstract class AbstractRed implements CachableRed {
 
@@ -56,10 +63,14 @@ public abstract class AbstractRed implements CachableRed {
     protected Map         props;
     protected SampleModel sm;
     protected ColorModel  cm;
-    protected int         tileGridXOff, tileGridYOff;
-    protected int         tileWidth,    tileHeight;
-    protected int         minTileX,     minTileY;
-    protected int         numXTiles,    numYTiles;
+    protected int tileGridXOff;
+    protected int tileGridYOff;
+    protected int tileWidth;
+    protected int tileHeight;
+    protected int minTileX;
+    protected int minTileY;
+    protected int numXTiles;
+    protected int numYTiles;
 
     /**
      * void constructor. The subclass must call one of the
@@ -129,8 +140,8 @@ public abstract class AbstractRed implements CachableRed {
                           ColorModel cm, SampleModel sm,
                           Map props) {
         init(src, bounds, cm, sm,
-             (src==null)?0:src.getTileGridXOffset(),
-             (src==null)?0:src.getTileGridYOffset(),
+             (src == null) ? 0 : src.getTileGridXOffset(),
+             (src == null) ? 0 : src.getTileGridYOffset(),
              props);
     }
 
@@ -185,9 +196,15 @@ public abstract class AbstractRed implements CachableRed {
         this.srcs         = new Vector(1);
         if (src != null) {
             this.srcs.add(src);
-            if (bounds == null) bounds = src.getBounds();
-            if (cm     == null) cm     = src.getColorModel();
-            if (sm     == null) sm     = src.getSampleModel();
+            if (bounds == null) {
+                bounds = src.getBounds();
+            }
+            if (cm     == null) {
+                cm     = src.getColorModel();
+            }
+            if (sm     == null) {
+                sm     = src.getSampleModel();
+            }
         }
 
         this.bounds       = bounds;
@@ -195,20 +212,22 @@ public abstract class AbstractRed implements CachableRed {
         this.tileGridYOff = tileGridYOff;
 
         this.props        = new HashMap();
-        if(props != null){
+        if (props != null) {
             this.props.putAll(props);
         }
 
-        if (cm == null)
-            cm = new ComponentColorModel
-                (ColorSpace.getInstance(ColorSpace.CS_GRAY),
+        if (cm == null) {
+            cm = new ComponentColorModel(
+                ColorSpace.getInstance(ColorSpace.CS_GRAY),
                  new int [] { 8 }, false, false, Transparency.OPAQUE,
                  DataBuffer.TYPE_BYTE);
+        }
 
         this.cm = cm;
 
-        if (sm == null)
+        if (sm == null) {
             sm = cm.createCompatibleSampleModel(bounds.width, bounds.height);
+        }
         this.sm = sm;
 
         // Recompute tileWidth/Height, minTileX/Y, numX/YTiles.
@@ -298,35 +317,42 @@ public abstract class AbstractRed implements CachableRed {
                         int tileGridXOff, int tileGridYOff,
                         Map props) {
         this.srcs = new Vector();
-        if(srcs != null){
+        if (srcs != null) {
             this.srcs.addAll(srcs);
-        }
-
-        if (srcs.size() != 0) {
-            CachableRed src = (CachableRed)srcs.get(0);
-            if (bounds == null) bounds = src.getBounds();
-            if (cm     == null) cm     = src.getColorModel();
-            if (sm     == null) sm     = src.getSampleModel();
+            if (srcs.size() != 0) {
+                CachableRed src = (CachableRed)srcs.get(0);
+                if (bounds == null) {
+                    bounds = src.getBounds();
+                }
+                if (cm     == null) {
+                    cm     = src.getColorModel();
+                }
+                if (sm     == null) {
+                    sm     = src.getSampleModel();
+                }
+            }
         }
 
         this.bounds       = bounds;
         this.tileGridXOff = tileGridXOff;
         this.tileGridYOff = tileGridYOff;
         this.props        = new HashMap();
-        if(props != null){
+        if (props != null) {
             this.props.putAll(props);
         }
 
-        if (cm == null)
-            cm = new ComponentColorModel
-                (ColorSpace.getInstance(ColorSpace.CS_GRAY),
+        if (cm == null) {
+            cm = new ComponentColorModel(
+                ColorSpace.getInstance(ColorSpace.CS_GRAY),
                  new int [] { 8 }, false, false, Transparency.OPAQUE,
                  DataBuffer.TYPE_BYTE);
+        }
 
         this.cm = cm;
 
-        if (sm == null)
+        if (sm == null) {
             sm = cm.createCompatibleSampleModel(bounds.width, bounds.height);
+        }
         this.sm = sm;
 
         // Recompute tileWidth/Height, minTileX/Y, numX/YTiles.
@@ -343,20 +369,23 @@ public abstract class AbstractRed implements CachableRed {
         this.tileWidth  = sm.getWidth();
         this.tileHeight = sm.getHeight();
 
-        int x1, y1, maxTileX, maxTileY;
+        int x1;
+        int y1;
+        int maxTileX;
+        int maxTileY;
 
         // This computes and caches important information about the
         // structure of the tile grid in general.
         minTileX = getXTile(bounds.x);
         minTileY = getYTile(bounds.y);
 
-        x1       = bounds.x + bounds.width-1;     // Xloc of right edge
+        x1       = bounds.x + bounds.width - 1;     // Xloc of right edge
         maxTileX = getXTile(x1);
-        numXTiles = maxTileX-minTileX+1;
+        numXTiles = maxTileX - minTileX + 1;
 
-        y1       = bounds.y + bounds.height-1;     // Yloc of right edge
+        y1       = bounds.y + bounds.height - 1;     // Yloc of right edge
         maxTileY = getYTile(y1);
-        numYTiles = maxTileY-minTileY+1;
+        numYTiles = maxTileY - minTileY + 1;
     }
 
 
@@ -428,12 +457,16 @@ public abstract class AbstractRed implements CachableRed {
 
     public Object getProperty(String name) {
         Object ret = props.get(name);
-        if (ret != null) return ret;
+        if (ret != null) {
+            return ret;
+        }
         Iterator i = srcs.iterator();
         while (i.hasNext()) {
             RenderedImage ri = (RenderedImage)i.next();
             ret = ri.getProperty(name);
-            if (ret != null) return ret;
+            if (ret != null) {
+                return ret;
+            }
         }
         return null;
     }
@@ -448,7 +481,7 @@ public abstract class AbstractRed implements CachableRed {
             RenderedImage ri = (RenderedImage)iter.next();
             String[] srcProps = ri.getPropertyNames();
             if (srcProps.length != 0) {
-                String[] tmp = new String[ret.length+srcProps.length];
+                String[] tmp = new String[ret.length + srcProps.length];
                 System.arraycopy(ret, 0, tmp, 0, ret.length);
                 System.arraycopy(srcProps, 0, tmp, ret.length, srcProps.length);
                 ret = tmp;
@@ -459,13 +492,15 @@ public abstract class AbstractRed implements CachableRed {
     }
 
     public Shape getDependencyRegion(int srcIndex, Rectangle outputRgn) {
-        if ((srcIndex < 0) || (srcIndex > srcs.size()))
-            throw new IndexOutOfBoundsException
-                ("Nonexistent source requested.");
+        if ((srcIndex < 0) || (srcIndex > srcs.size())) {
+            throw new IndexOutOfBoundsException(
+                "Nonexistent source requested.");
+        }
 
         // Return empty rect if they don't intersect.
-        if (!outputRgn.intersects(bounds))
+        if (!outputRgn.intersects(bounds)) {
             return new Rectangle();
+        }
 
         // We only depend on our source for stuff that is inside
         // our bounds...
@@ -473,13 +508,15 @@ public abstract class AbstractRed implements CachableRed {
     }
 
     public Shape getDirtyRegion(int srcIndex, Rectangle inputRgn) {
-        if (srcIndex != 0)
-            throw new IndexOutOfBoundsException
-                ("Nonexistent source requested.");
+        if (srcIndex != 0) {
+            throw new IndexOutOfBoundsException(
+                "Nonexistent source requested.");
+        }
 
         // Return empty rect if they don't intersect.
-        if (!inputRgn.intersects(bounds))
+        if (!inputRgn.intersects(bounds)) {
             return new Rectangle();
+        }
 
         // Changes in the input region don't propogate outside our
         // bounds.
@@ -504,8 +541,8 @@ public abstract class AbstractRed implements CachableRed {
     }
 
     public Raster getData(Rectangle rect) {
-        SampleModel smRet = sm.createCompatibleSampleModel
-            (rect.width, rect.height);
+        SampleModel smRet = sm.createCompatibleSampleModel(
+            rect.width, rect.height);
 
         Point pt = new Point(rect.x, rect.y);
         WritableRaster wr = Raster.createWritableRaster(smRet, pt);
@@ -520,12 +557,13 @@ public abstract class AbstractRed implements CachableRed {
      * @return The tile index under xloc (may be outside tile grid).
      */
     public final int getXTile(int xloc) {
-        int tgx = xloc-tileGridXOff;
+        int tgx = xloc - tileGridXOff;
         // We need to round to -infinity...
-        if (tgx>=0)
-            return tgx/tileWidth;
-        else
-            return (tgx-tileWidth+1)/tileWidth;
+        if (tgx >= 0) {
+            return tgx / tileWidth;
+        } else {
+            return (tgx - tileWidth + 1) / tileWidth;
+        }
     }
 
     /**
@@ -534,12 +572,13 @@ public abstract class AbstractRed implements CachableRed {
      * @return The tile index under yloc (may be outside tile grid).
      */
     public final int getYTile(int yloc) {
-        int tgy = yloc-tileGridYOff;
+        int tgy = yloc - tileGridYOff;
         // We need to round to -infinity...
-        if (tgy>=0)
-            return tgy/tileHeight;
-        else
-            return (tgy-tileHeight+1)/tileHeight;
+        if (tgy >= 0) {
+            return tgy / tileHeight;
+        } else {
+            return (tgy - tileHeight + 1) / tileHeight;
+        }
     }
 
     /**
@@ -551,26 +590,36 @@ public abstract class AbstractRed implements CachableRed {
     public void copyToRaster(WritableRaster wr) {
         int tx0 = getXTile(wr.getMinX());
         int ty0 = getYTile(wr.getMinY());
-        int tx1 = getXTile(wr.getMinX()+wr.getWidth() -1);
-        int ty1 = getYTile(wr.getMinY()+wr.getHeight()-1);
+        int tx1 = getXTile(wr.getMinX() + wr.getWidth() - 1);
+        int ty1 = getYTile(wr.getMinY() + wr.getHeight() - 1);
 
-        if (tx0 < minTileX) tx0 = minTileX;
-        if (ty0 < minTileY) ty0 = minTileY;
+        if (tx0 < minTileX) {
+            tx0 = minTileX;
+        }
+        if (ty0 < minTileY) {
+            ty0 = minTileY;
+        }
 
-        if (tx1 >= minTileX+numXTiles) tx1 = minTileX+numXTiles-1;
-        if (ty1 >= minTileY+numYTiles) ty1 = minTileY+numYTiles-1;
+        if (tx1 >= minTileX + numXTiles) {
+            tx1 = minTileX + numXTiles - 1;
+        }
+        if (ty1 >= minTileY + numYTiles) {
+            ty1 = minTileY + numYTiles - 1;
+        }
 
-        final boolean is_INT_PACK =
+        final boolean isIntPack =
             GraphicsUtil.is_INT_PACK_Data(getSampleModel(), false);
 
-        for (int y=ty0; y<=ty1; y++)
-            for (int x=tx0; x<=tx1; x++) {
+        for (int y = ty0; y <= ty1; y++) {
+            for (int x = tx0; x <= tx1; x++) {
                 Raster r = getTile(x, y);
-                if (is_INT_PACK)
+                if (isIntPack) {
                     GraphicsUtil.copyData_INT_PACK(r, wr);
-                else
+                } else {
                     GraphicsUtil.copyData_FALLBACK(r, wr);
+                }
             }
+        }
     }
 
 
@@ -587,14 +636,15 @@ public abstract class AbstractRed implements CachableRed {
      *   falles outside of the bounds of the tile grid for the image.
      */
     public WritableRaster makeTile(int tileX, int tileY) {
-        if ((tileX < minTileX) || (tileX >= minTileX+numXTiles) ||
-            (tileY < minTileY) || (tileY >= minTileY+numYTiles))
-            throw new IndexOutOfBoundsException
-                ("Requested Tile (" + tileX + ',' + tileY +
-                 ") lies outside the bounds of image");
+        if ((tileX < minTileX) || (tileX >= minTileX + numXTiles)
+            || (tileY < minTileY) || (tileY >= minTileY + numYTiles)) {
+            throw new IndexOutOfBoundsException(
+                "Requested Tile (" + tileX + ',' + tileY
+                 + ") lies outside the bounds of image");
+        }
 
-        Point pt = new Point(tileGridXOff+tileX*tileWidth,
-                             tileGridYOff+tileY*tileHeight);
+        Point pt = new Point(tileGridXOff + tileX * tileWidth,
+                             tileGridYOff + tileY * tileHeight);
 
         WritableRaster wr;
         wr = Raster.createWritableRaster(sm, pt);
@@ -618,19 +668,27 @@ public abstract class AbstractRed implements CachableRed {
 
         int x0 = wr.getMinX();
         int y0 = wr.getMinY();
-        int x1 = x0+wr.getWidth() -1;
-        int y1 = y0+wr.getHeight()-1;
+        int x1 = x0 + wr.getWidth() - 1;
+        int y1 = y0 + wr.getHeight() - 1;
 
-        if ((x0 < bounds.x) || (x1 >= (bounds.x+bounds.width)) ||
-            (y0 < bounds.y) || (y1 >= (bounds.y+bounds.height))) {
+        if ((x0 < bounds.x) || (x1 >= (bounds.x + bounds.width))
+            || (y0 < bounds.y) || (y1 >= (bounds.y + bounds.height))) {
             // Part of this raster lies outside our bounds so subset
             // it so it only advertises the stuff inside our bounds.
-            if (x0 < bounds.x) x0 = bounds.x;
-            if (y0 < bounds.y) y0 = bounds.y;
-            if (x1 >= (bounds.x+bounds.width))  x1 = bounds.x+bounds.width-1;
-            if (y1 >= (bounds.y+bounds.height)) y1 = bounds.y+bounds.height-1;
+            if (x0 < bounds.x) {
+                x0 = bounds.x;
+            }
+            if (y0 < bounds.y) {
+                y0 = bounds.y;
+            }
+            if (x1 >= (bounds.x + bounds.width)) {
+                x1 = bounds.x + bounds.width - 1;
+            }
+            if (y1 >= (bounds.y + bounds.height)) {
+                y1 = bounds.y + bounds.height - 1;
+            }
 
-            wr = wr.createWritableChild(x0, y0, x1-x0+1, y1-y0+1,
+            wr = wr.createWritableChild(x0, y0, x1 - x0 + 1, y1 - y0 + 1,
                                         x0, y0, null);
         }
         return wr;
@@ -646,7 +704,7 @@ public abstract class AbstractRed implements CachableRed {
         Rectangle cpR  = srcR.intersection(dstR);
 
         int [] samples = null;
-        for (int y=cpR.y; y< cpR.y+cpR.height; y++) {
+        for (int y = cpR.y; y < cpR.y + cpR.height; y++) {
             samples = src.getSamples(cpR.x, y, cpR.width, 1, srcBand, samples);
             dst.setSamples(cpR.x, y, cpR.width, 1, dstBand, samples);
         }
