@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: Any2sRGBRed.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: Any2sRGBRed.java 1681108 2015-05-22 13:26:12Z ssteiner $ */
 
 package org.apache.xmlgraphics.image.rendered;
 
@@ -33,16 +33,26 @@ import java.awt.image.WritableRaster;
 
 import org.apache.xmlgraphics.image.GraphicsUtil;
 
+// CSOFF: ConstantName
+// CSOFF: MethodName
+// CSOFF: MultipleVariableDeclarations
+// CSOFF: NeedBraces
+// CSOFF: OperatorWrap
+// CSOFF: WhitespaceAfter
+// CSOFF: WhitespaceAround
+
 /**
  * This function will tranform an image from any colorspace into a
  * luminance image.  The alpha channel if any will be copied to the
  * new image.
  *
- * @author <a href="mailto:Thomas.DeWeeese@Kodak.com">Thomas DeWeese</a>
- * @version $Id: Any2sRGBRed.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+ * @version $Id: Any2sRGBRed.java 1681108 2015-05-22 13:26:12Z ssteiner $
+ *
+ * Originally authored by Thomas DeWeese.
+ */
 public class Any2sRGBRed extends AbstractRed {
 
-    boolean srcIsLsRGB = false;
+    boolean srcIsLsRGB;
 
     /**
      * Construct a luminace image from src.
@@ -50,7 +60,7 @@ public class Any2sRGBRed extends AbstractRed {
      * @param src The image to convert to a luminance image
      */
     public Any2sRGBRed(CachableRed src) {
-        super(src,src.getBounds(),
+        super(src, src.getBounds(),
               fixColorModel(src),
               fixSampleModel(src),
               src.getTileGridXOffset(),
@@ -58,28 +68,45 @@ public class Any2sRGBRed extends AbstractRed {
               null);
 
         ColorModel srcCM = src.getColorModel();
-        if (srcCM == null) return;
+        if (srcCM == null) {
+            return;
+        }
         ColorSpace srcCS = srcCM.getColorSpace();
-        if (srcCS == ColorSpace.getInstance(ColorSpace.CS_LINEAR_RGB))
+        if (srcCS == ColorSpace.getInstance(ColorSpace.CS_LINEAR_RGB)) {
             srcIsLsRGB = true;
+        }
     }
 
     public static boolean is_INT_PACK_COMP(SampleModel sm) {
-        if(!(sm instanceof SinglePixelPackedSampleModel)) return false;
+        if (!(sm instanceof SinglePixelPackedSampleModel)) {
+            return false;
+        }
 
         // Check transfer types
-        if(sm.getDataType() != DataBuffer.TYPE_INT)       return false;
+        if (sm.getDataType() != DataBuffer.TYPE_INT) {
+            return false;
+        }
 
         SinglePixelPackedSampleModel sppsm;
         sppsm = (SinglePixelPackedSampleModel)sm;
 
         int [] masks = sppsm.getBitMasks();
-        if ((masks.length != 3) && (masks.length != 4)) return false;
-        if(masks[0] != 0x00ff0000) return false;
-        if(masks[1] != 0x0000ff00) return false;
-        if(masks[2] != 0x000000ff) return false;
-        if ((masks.length == 4) &&
-            (masks[3] != 0xff000000)) return false;
+        if ((masks.length != 3) && (masks.length != 4)) {
+            return false;
+        }
+        if (masks[0] != 0x00ff0000) {
+            return false;
+        }
+        if (masks[1] != 0x0000ff00) {
+            return false;
+        }
+        if (masks[2] != 0x000000ff) {
+            return false;
+        }
+        if ((masks.length == 4)
+            && (masks[3] != 0xff000000)) {
+            return false;
+        }
 
         return true;
    }
@@ -97,17 +124,18 @@ public class Any2sRGBRed extends AbstractRed {
      */
     private static final int[] linearToSRGBLut = new int[256];
     static {
-        final double scale = 1.0/255;
-        final double exp   = 1.0/GAMMA;
+        final double scale = 1.0 / 255;
+        final double exp   = 1.0 / GAMMA;
         // System.out.print("L2S: ");
-        for(int i=0; i<256; i++){
-            double value = i*scale;
-            if(value <= 0.0031308)
+        for (int i = 0; i < 256; i++) {
+            double value = i * scale;
+            if (value <= 0.0031308) {
                 value *= 12.92;
-            else
+            } else {
                 value = 1.055 * Math.pow(value, exp) - 0.055;
+            }
 
-            linearToSRGBLut[i] = (int)Math.round(value*255.);
+            linearToSRGBLut[i] = (int)Math.round(value * 255.);
             // System.out.print(linearToSRGBLut[i] + ",");
         }
         // System.out.println("");
@@ -120,29 +148,30 @@ public class Any2sRGBRed extends AbstractRed {
         DataBufferInt db = (DataBufferInt)wr.getDataBuffer();
 
         final int     srcBase
-            = (db.getOffset() +
-               sm.getOffset(wr.getMinX()-wr.getSampleModelTranslateX(),
-                            wr.getMinY()-wr.getSampleModelTranslateY()));
+            = (db.getOffset()
+               + sm.getOffset(wr.getMinX() - wr.getSampleModelTranslateX(),
+                            wr.getMinY() - wr.getSampleModelTranslateY()));
         // Access the pixel data array
         final int[] pixels   = db.getBankData()[0];
         final int width      = wr.getWidth();
         final int height     = wr.getHeight();
         final int scanStride = sm.getScanlineStride();
 
-        int end, pix;
+        int end;
+        int pix;
 
         // For alpha premult we need to multiply all comps.
-        for (int y=0; y<height; y++) {
-            int sp  = srcBase + y*scanStride;
+        for (int y = 0; y < height; y++) {
+            int sp  = srcBase + y * scanStride;
             end = sp + width;
 
-            while (sp<end) {
+            while (sp < end) {
                 pix = pixels[sp];
                 pixels[sp] =
-                    ((     pix      &0xFF000000)|
-                     (lut[(pix>>>16)&0xFF]<<16) |
-                     (lut[(pix>>> 8)&0xFF]<< 8) |
-                     (lut[(pix     )&0xFF]    ));
+                    ((pix & 0xFF000000)
+                     | (lut[(pix >>> 16) & 0xFF] << 16)
+                     | (lut[(pix >>> 8) & 0xFF] << 8)
+                     | (lut[pix & 0xFF]));
                 sp++;
             }
         }
@@ -159,11 +188,12 @@ public class Any2sRGBRed extends AbstractRed {
 
 
         // Fast case, Linear SRGB source, INT Pack writable raster...
-        if (srcIsLsRGB &&
-            is_INT_PACK_COMP(wr.getSampleModel())) {
+        if (srcIsLsRGB
+            && is_INT_PACK_COMP(wr.getSampleModel())) {
             src.copyData(wr);
-            if (srcCM.hasAlpha())
+            if (srcCM.hasAlpha()) {
                 GraphicsUtil.coerceData(wr, srcCM, false);
+            }
             applyLut_INT(wr, linearToSRGBLut);
             return wr;
         }
@@ -207,8 +237,8 @@ public class Any2sRGBRed extends AbstractRed {
             return wr;
         }
 
-        if (srcCM.getColorSpace() ==
-            ColorSpace.getInstance(ColorSpace.CS_GRAY)) {
+        if (srcCM.getColorSpace()
+            == ColorSpace.getInstance(ColorSpace.CS_GRAY)) {
 
             // This is a little bit of a hack.  There is only
             // a linear grayscale ICC profile in the JDK so
@@ -246,27 +276,31 @@ public class Any2sRGBRed extends AbstractRed {
             // No transform needed, just reformat data...
             // System.out.println("Bypassing");
 
-            if (is_INT_PACK_COMP(srcSM))
+            if (is_INT_PACK_COMP(srcSM)) {
                 src.copyData(wr);
-            else
+            } else {
                 GraphicsUtil.copyData(src.getData(wr.getBounds()), wr);
+            }
 
             return wr;
         }
 
         Raster srcRas = src.getData(wr.getBounds());
+        assert srcRas instanceof WritableRaster;
         WritableRaster srcWr  = (WritableRaster)srcRas;
 
         // Divide out alpha if we have it.  We need to do this since
         // the color convert may not be a linear operation which may
         // lead to out of range values.
         ColorModel srcBICM = srcCM;
-        if (srcCM.hasAlpha())
+        if (srcCM.hasAlpha()) {
             srcBICM = GraphicsUtil.coerceData(srcWr, srcCM, false);
+        }
 
-        BufferedImage srcBI, dstBI;
+        BufferedImage srcBI;
+        BufferedImage dstBI;
         srcBI = new BufferedImage(srcBICM,
-                                  srcWr.createWritableTranslatedChild(0,0),
+                                  srcWr.createWritableTranslatedChild(0, 0),
                                   false,
                                   null);
 
@@ -279,13 +313,15 @@ public class Any2sRGBRed extends AbstractRed {
 
         // System.out.println("After filter:");
 
-        WritableRaster wr00 = wr.createWritableTranslatedChild(0,0);
-        for (int i=0; i<dstCM.getColorSpace().getNumComponents(); i++)
+        WritableRaster wr00 = wr.createWritableTranslatedChild(0, 0);
+        for (int i = 0; i < dstCM.getColorSpace().getNumComponents(); i++) {
             copyBand(dstBI.getRaster(), i, wr00,    i);
+        }
 
-        if (dstCM.hasAlpha())
-            copyBand(srcWr, srcSM.getNumBands()-1,
-                     wr,    getSampleModel().getNumBands()-1);
+        if (dstCM.hasAlpha()) {
+            copyBand(srcWr, srcSM.getNumBands() - 1,
+                     wr,    getSampleModel().getNumBands() - 1);
+        }
         return wr;
     }
 
@@ -297,12 +333,12 @@ public class Any2sRGBRed extends AbstractRed {
     protected static ColorModel fixColorModel(CachableRed src) {
         ColorModel  cm = src.getColorModel();
         if (cm != null) {
-            if (cm.hasAlpha())
+            if (cm.hasAlpha()) {
                 return GraphicsUtil.sRGB_Unpre;
+            }
 
             return GraphicsUtil.sRGB;
-        }
-        else {
+        } else {
             // No ColorModel so try to make some intelligent
             // decisions based just on the number of bands...
             // 1 bands -> replicated into RGB
@@ -318,8 +354,9 @@ public class Any2sRGBRed extends AbstractRed {
                 return GraphicsUtil.sRGB_Unpre;
             case 3:
                 return GraphicsUtil.sRGB;
+            default:
+                return GraphicsUtil.sRGB_Unpre;
             }
-            return GraphicsUtil.sRGB_Unpre;
         }
     }
 
@@ -334,9 +371,9 @@ public class Any2sRGBRed extends AbstractRed {
 
         boolean alpha = false;
 
-        if (cm != null)
+        if (cm != null) {
             alpha = cm.hasAlpha();
-        else {
+        } else {
             switch (sm.getNumBands()) {
             case 1: case 3:
                 alpha = false;
@@ -346,17 +383,18 @@ public class Any2sRGBRed extends AbstractRed {
                 break;
             }
         }
-        if (alpha)
-            return new SinglePixelPackedSampleModel
-                (DataBuffer.TYPE_INT,
+        if (alpha) {
+            return new SinglePixelPackedSampleModel(
+                DataBuffer.TYPE_INT,
                  sm.getWidth(),
                  sm.getHeight(),
                  new int [] {0xFF0000, 0xFF00, 0xFF, 0xFF000000});
-        else
-            return new SinglePixelPackedSampleModel
-                (DataBuffer.TYPE_INT,
+        } else {
+            return new SinglePixelPackedSampleModel(
+                DataBuffer.TYPE_INT,
                  sm.getWidth(),
                  sm.getHeight(),
                  new int [] {0xFF0000, 0xFF00, 0xFF});
+        }
     }
 }
