@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: BufferedImageCachableRed.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: BufferedImageCachableRed.java 1576437 2014-03-11 17:49:35Z vhennebert $ */
 
 package org.apache.xmlgraphics.image.rendered;
 
@@ -26,14 +26,19 @@ import java.awt.image.WritableRaster;
 
 import org.apache.xmlgraphics.image.GraphicsUtil;
 
+// CSOFF: NeedBraces
+// CSOFF: WhitespaceAfter
+// CSOFF: WhitespaceAround
+
 /**
  * This implements CachableRed based on a BufferedImage.
  * You can use this to wrap a BufferedImage that you want to
  * appear as a CachableRed.
  * It essentially ignores the dependency and dirty region methods.
  *
- * @author <a href="mailto:Thomas.DeWeeese@Kodak.com">Thomas DeWeese</a>
- * @version $Id: BufferedImageCachableRed.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+ * Originally authored by Thomas DeWeese.
+ * @version $Id: BufferedImageCachableRed.java 1576437 2014-03-11 17:49:35Z vhennebert $
+ */
 public class BufferedImageCachableRed extends AbstractRed {
     // The bufferedImage that we wrap...
     BufferedImage bi;
@@ -84,7 +89,7 @@ public class BufferedImageCachableRed extends AbstractRed {
     }
 
     public Raster getTile(int tileX, int tileY) {
-        return bi.getTile(tileX,tileY);
+        return bi.getTile(tileX, tileY);
     }
 
     public Raster getData() {
@@ -95,20 +100,21 @@ public class BufferedImageCachableRed extends AbstractRed {
     public Raster getData(Rectangle rect) {
         Rectangle r = (Rectangle)rect.clone();
 
-        if (!r.intersects(getBounds()))
+        if (!r.intersects(getBounds())) {
             return null;
+        }
         r = r.intersection(getBounds());
-        r.translate(-getMinX(), - getMinY());
+        r.translate(-getMinX(), -getMinY());
 
         Raster ret = bi.getData(r);
-        return ret.createTranslatedChild(ret.getMinX()+getMinX(),
-                                         ret.getMinY()+getMinY());
+        return ret.createTranslatedChild(ret.getMinX() + getMinX(),
+                                         ret.getMinY() + getMinY());
     }
 
     public WritableRaster copyData(WritableRaster wr) {
-        WritableRaster wr2 = wr.createWritableTranslatedChild
-            (wr.getMinX()-getMinX(),
-             wr.getMinY()-getMinY());
+        WritableRaster wr2 = wr.createWritableTranslatedChild(
+            wr.getMinX() - getMinX(),
+             wr.getMinY() - getMinY());
 
         GraphicsUtil.copyData(bi.getRaster(), wr2);
 
