@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: RenderedImageCachableRed.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: RenderedImageCachableRed.java 1576437 2014-03-11 17:49:35Z vhennebert $ */
 
 package org.apache.xmlgraphics.image.rendered;
 
@@ -29,22 +29,28 @@ import java.awt.image.SampleModel;
 import java.awt.image.WritableRaster;
 import java.util.Vector;
 
+// CSOFF: NeedBraces
+// CSOFF: WhitespaceAround
+
 /**
  * This implements CachableRed around a RenderedImage.
  * You can use this to wrap a RenderedImage that you want to
  * appear as a CachableRed.
  * It essentially ignores the dependency and dirty region methods.
  *
- * @author <a href="mailto:Thomas.DeWeeese@Kodak.com">Thomas DeWeese</a>
- * @version $Id: RenderedImageCachableRed.java 750418 2009-03-05 11:03:54Z vhennebert $
+ * @version $Id: RenderedImageCachableRed.java 1576437 2014-03-11 17:49:35Z vhennebert $
+ *
+ * Originally authored by Thomas DeWeese.
  */
 public class RenderedImageCachableRed implements CachableRed {
 
     public static CachableRed wrap(RenderedImage ri) {
-        if (ri instanceof CachableRed)
+        if (ri instanceof CachableRed) {
             return (CachableRed) ri;
-        if (ri instanceof BufferedImage)
+        }
+        if (ri instanceof BufferedImage) {
             return new BufferedImageCachableRed((BufferedImage)ri);
+        }
         return new RenderedImageCachableRed(ri);
     }
 
@@ -52,8 +58,8 @@ public class RenderedImageCachableRed implements CachableRed {
     private Vector srcs = new Vector(0);
 
     public RenderedImageCachableRed(RenderedImage src) {
-        if(src == null){
-            throw new IllegalArgumentException();
+        if (src == null) {
+            throw new NullPointerException();
         }
         this.src = src;
     }
@@ -145,12 +151,12 @@ public class RenderedImageCachableRed implements CachableRed {
     }
 
     public Shape getDependencyRegion(int srcIndex, Rectangle outputRgn) {
-        throw new IndexOutOfBoundsException
-            ("Nonexistant source requested.");
+        throw new IndexOutOfBoundsException(
+            "Nonexistant source requested.");
     }
 
     public Shape getDirtyRegion(int srcIndex, Rectangle inputRgn) {
-        throw new IndexOutOfBoundsException
-            ("Nonexistant source requested.");
+        throw new IndexOutOfBoundsException(
+            "Nonexistant source requested.");
     }
 }
