@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: AbstractPSDocumentGraphics2D.java 1345683 2012-06-03 14:50:33Z gadams $ */
+/* $Id: AbstractPSDocumentGraphics2D.java 1681108 2015-05-22 13:26:12Z ssteiner $ */
 
 package org.apache.xmlgraphics.java2d.ps;
 
@@ -34,14 +34,14 @@ import org.apache.xmlgraphics.ps.PSProcSets;
  * is used to create a full document around the PostScript rendering from
  * <tt>PSGraphics2D</tt>.
  *
- * @version $Id: AbstractPSDocumentGraphics2D.java 1345683 2012-06-03 14:50:33Z gadams $
+ * @version $Id: AbstractPSDocumentGraphics2D.java 1681108 2015-05-22 13:26:12Z ssteiner $
  * @see org.apache.xmlgraphics.java2d.ps.PSGraphics2D
  *
  * Originally authored by Keiron Liddle.
  */
 public abstract class AbstractPSDocumentGraphics2D extends PSGraphics2D {
 
-    protected static final Integer ZERO = new Integer(0);
+    protected static final Integer ZERO = 0;
 
     protected int width;
     protected int height;
@@ -274,7 +274,7 @@ public abstract class AbstractPSDocumentGraphics2D extends PSGraphics2D {
 
         //Finish document
         gen.writeDSCComment(DSCConstants.TRAILER);
-        gen.writeDSCComment(DSCConstants.PAGES, new Integer(this.pagecount));
+        gen.writeDSCComment(DSCConstants.PAGES, this.pagecount);
         gen.writeDSCComment(DSCConstants.EOF);
         gen.flush();
     }
