@@ -15,15 +15,17 @@
  * limitations under the License.
  */
 
-/* $Id: ImageEncodingHelper.java 884159 2009-11-25 15:53:41Z jeremias $ */
+/* $Id: ImageEncodingHelper.java 1722889 2016-01-04 15:24:13Z ssteiner $ */
 
 package org.apache.xmlgraphics.ps;
 
 import java.awt.color.ColorSpace;
+import java.awt.image.BufferedImage;
 import java.awt.image.ColorModel;
 import java.awt.image.ComponentColorModel;
 import java.awt.image.DataBuffer;
 import java.awt.image.DataBufferByte;
+import java.awt.image.DirectColorModel;
 import java.awt.image.IndexColorModel;
 import java.awt.image.PixelInterleavedSampleModel;
 import java.awt.image.Raster;
@@ -31,6 +33,7 @@ import java.awt.image.RenderedImage;
 import java.awt.image.SampleModel;
 import java.io.IOException;
 import java.io.OutputStream;
+import java.util.Arrays;
 
 import org.apache.xmlgraphics.image.GraphicsUtil;
 
@@ -47,13 +50,18 @@ public class ImageEncodingHelper {
     private ColorModel encodedColorModel;
     private boolean firstTileDump;
     private boolean enableCMYK;
+    private boolean isBGR;
+    private boolean isKMYC;
+    private boolean outputbw;
+    private boolean bwinvert;
 
     /**
      * Main constructor
      * @param image the image
      */
     public ImageEncodingHelper(RenderedImage image) {
-        this(image, false);
+        this(image, true);
+        outputbw = image instanceof BufferedImage;
     }
 
     /**
@@ -110,7 +118,16 @@ public class ImageEncodingHelper {
     }
 
     private void writeRGBTo(OutputStream out) throws IOException {
-        encodeRenderedImageAsRGB(image, out);
+        boolean encoded = encodeRenderedImageWithDirectColorModelAsRGB(image, out);
+        if (encoded) {
+            return;
+        }
+        encodeRenderedImageAsRGB(image, out, outputbw, bwinvert);
+    }
+
+    public static void encodeRenderedImageAsRGB(RenderedImage image, OutputStream out)
+            throws IOException {
+        encodeRenderedImageAsRGB(image, out, false, false);
     }
 
     /**
@@ -119,9 +136,9 @@ public class ImageEncodingHelper {
      * @param out the OutputStream to write the pixels to
      * @throws IOException if an I/O error occurs
      */
-    public static void encodeRenderedImageAsRGB(RenderedImage image, OutputStream out)
-                throws IOException {
-        Raster raster = image.getData();
+    public static void encodeRenderedImageAsRGB(RenderedImage image, OutputStream out,
+            boolean outputbw, boolean bwinvert) throws IOException {
+        Raster raster = getRaster(image);
         Object data;
         int nbands = raster.getNumBands();
         int dataType = raster.getDataBuffer().getDataType();
@@ -130,7 +147,7 @@ public class ImageEncodingHelper {
             data = new byte[nbands];
             break;
         case DataBuffer.TYPE_USHORT:
-            data = new short[nbands];
+            data = null;
             break;
         case DataBuffer.TYPE_INT:
             data = new int[nbands];
@@ -142,24 +159,94 @@ public class ImageEncodingHelper {
             data = new double[nbands];
             break;
         default:
-            throw new IllegalArgumentException("Unknown data buffer type: "+
-                                               dataType);
+            throw new IllegalArgumentException("Unknown data buffer type: " + dataType);
         }
 
         ColorModel colorModel = image.getColorModel();
         int w = image.getWidth();
         int h = image.getHeight();
-        byte[] buf = new byte[w * 3];
+        int numDataElements = 3;
+        if (colorModel.getPixelSize() == 1 && outputbw) {
+            numDataElements = 1;
+        }
+
+        byte[] buf = new byte[w * numDataElements];
+
         for (int y = 0; y < h; y++) {
             int idx = -1;
             for (int x = 0; x < w; x++) {
                 int rgb = colorModel.getRGB(raster.getDataElements(x, y, data));
+                if (numDataElements > 1) {
+                    buf[++idx] = (byte)(rgb >> 16);
+                    buf[++idx] = (byte)(rgb >> 8);
+                } else if (bwinvert && rgb == -1) {
+                    rgb = 1;
+                }
+                buf[++idx] = (byte)(rgb);
+            }
+            out.write(buf);
+        }
+    }
+
+    /**
+     * Writes a RenderedImage to an OutputStream. This method optimizes the encoding
+     * of the {@link DirectColorModel} as it is returned by {@link ColorModel#getRGBdefault}.
+     * @param image the image
+     * @param out the OutputStream to write the pixels to
+     * @return true if this method encoded this image, false if the image is incompatible
+     * @throws IOException if an I/O error occurs
+     */
+    public static boolean encodeRenderedImageWithDirectColorModelAsRGB(
+            RenderedImage image, OutputStream out) throws IOException {
+        ColorModel cm = image.getColorModel();
+        if (cm.getColorSpace() != ColorSpace.getInstance(ColorSpace.CS_sRGB)) {
+            return false; //Need to go through color management
+        }
+        if (!(cm instanceof DirectColorModel)) {
+            return false; //Only DirectColorModel is supported here
+        }
+        DirectColorModel dcm = (DirectColorModel)cm;
+        final int[] templateMasks = new int[]
+                {0x00ff0000 /*R*/, 0x0000ff00 /*G*/, 0x000000ff /*B*/, 0xff000000 /*A*/};
+        int[] masks = dcm.getMasks();
+        if (!Arrays.equals(templateMasks, masks)) {
+            return false; //no flexibility here right now, might never be used anyway
+        }
+
+        Raster raster = getRaster(image);
+        int dataType = raster.getDataBuffer().getDataType();
+        if (dataType != DataBuffer.TYPE_INT) {
+            return false; //not supported
+        }
+
+        int w = image.getWidth();
+        int h = image.getHeight();
+
+        int[] data = new int[w];
+        byte[] buf = new byte[w * 3];
+        for (int y = 0; y < h; y++) {
+            int idx = -1;
+            raster.getDataElements(0, y, w, 1, data);
+            for (int x = 0; x < w; x++) {
+                int rgb = data[x];
                 buf[++idx] = (byte)(rgb >> 16);
                 buf[++idx] = (byte)(rgb >> 8);
                 buf[++idx] = (byte)(rgb);
             }
             out.write(buf);
         }
+
+        return true;
+    }
+
+    private static Raster getRaster(RenderedImage image) {
+        if (image instanceof BufferedImage) {
+            return ((BufferedImage)image).getRaster();
+        } else {
+            //Note: this copies the image data (double memory consumption)
+            //TODO Investigate encoding in stripes: RenderedImage.copyData(WritableRaster)
+            return image.getData();
+        }
     }
 
     /**
@@ -234,7 +321,28 @@ public class ImageEncodingHelper {
             Raster raster = image.getTile(0, 0);
             DataBuffer buffer = raster.getDataBuffer();
             if (buffer instanceof DataBufferByte) {
-                out.write(((DataBufferByte)buffer).getData());
+                byte[] bytes = ((DataBufferByte) buffer).getData();
+                // see determineEncodingColorModel() to see why we permute B and R here
+                if (isBGR) {
+                    byte[] bytesPermutated = new byte[bytes.length];
+                    for (int i = 0; i < bytes.length; i += 3) {
+                        bytesPermutated[i] = bytes[i + 2];
+                        bytesPermutated[i + 1] = bytes[i + 1];
+                        bytesPermutated[i + 2] = bytes[i];
+                    }
+                    out.write(bytesPermutated);
+                } else if (isKMYC) {
+                    byte[] bytesPermutated = new byte[bytes.length];
+                    for (int i = 0; i < bytes.length; i += 4) {
+                        bytesPermutated[i] = bytes[i + 3];
+                        bytesPermutated[i + 1] = bytes[i + 2];
+                        bytesPermutated[i + 2] = bytes[i + 1];
+                        bytesPermutated[i + 3] = bytes[i];
+                    }
+                    out.write(bytesPermutated);
+                } else {
+                    out.write(bytes);
+                }
                 return true;
             }
         }
@@ -285,12 +393,26 @@ public class ImageEncodingHelper {
                     piSampleModel = (PixelInterleavedSampleModel)sampleModel;
                     int[] offsets = piSampleModel.getBandOffsets();
                     for (int i = 0; i < offsets.length; i++) {
-                        if (offsets[i] != i) {
+                        if (offsets[i] != i && offsets[i] != offsets.length - 1 - i) {
                             //Don't encode directly as samples are not next to each other
                             //i.e. offsets are not 012 (RGB) or 0123 (CMYK)
+                            // let also pass 210 BGR and 3210 (KYMC); 3210 will be skipped below
+                            // if 210 (BGR) the B and R bytes will be permuted later in optimizeWriteTo()
                             return;
                         }
                     }
+                    // check if we are in a BGR case; this is added here as a workaround for bug fix
+                    // http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6549882 that causes some PNG
+                    // images to be loaded as BGR with the consequence that performance was being impacted
+                    this.isBGR = false;
+                    if (offsets.length == 3 && offsets[0] == 2 && offsets[1] == 1 && offsets[2] == 0) {
+                        this.isBGR = true;
+                    }
+                    // make sure we did not get here due to a KMYC image
+                    if (offsets.length == 4 && offsets[0] == 3 && offsets[1] == 2 && offsets[2] == 1
+                            && offsets[3] == 0) {
+                        isKMYC = true;
+                    }
                 }
                 if (cm.getTransferType() == DataBuffer.TYPE_BYTE
                         && buffer.getOffset() == 0
@@ -345,7 +467,7 @@ public class ImageEncodingHelper {
      */
     public static void encodePackedColorComponents(RenderedImage image, OutputStream out)
                 throws IOException {
-        ImageEncodingHelper helper = new ImageEncodingHelper(image, true);
+        ImageEncodingHelper helper = new ImageEncodingHelper(image);
         helper.encode(out);
     }
 
@@ -376,7 +498,9 @@ public class ImageEncodingHelper {
         public String getImplicitFilter() {
             return null; //No implicit filters with RenderedImage instances
         }
-
     }
 
+    public void setBWInvert(boolean v) {
+        bwinvert = v;
+    }
 }
