@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,41 +15,50 @@
  * limitations under the License.
  */
 
-/* $Id: PSImageUtils.java 604971 2007-12-17 19:05:41Z jeremias $ */
- 
+/* $Id: PSImageUtils.java 1557632 2014-01-12 23:59:42Z lbernardo $ */
+
 package org.apache.xmlgraphics.ps;
 
+import java.awt.Color;
 import java.awt.Dimension;
 import java.awt.color.ColorSpace;
 import java.awt.geom.Dimension2D;
 import java.awt.geom.Rectangle2D;
 import java.awt.image.ColorModel;
 import java.awt.image.DataBuffer;
+import java.awt.image.DataBufferByte;
 import java.awt.image.IndexColorModel;
 import java.awt.image.Raster;
 import java.awt.image.RenderedImage;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.util.Arrays;
 
 import org.apache.commons.io.IOUtils;
+
 import org.apache.xmlgraphics.util.io.ASCII85OutputStream;
 import org.apache.xmlgraphics.util.io.Finalizable;
 import org.apache.xmlgraphics.util.io.FlateEncodeOutputStream;
 import org.apache.xmlgraphics.util.io.RunLengthEncodeOutputStream;
 
+// CSOFF: HideUtilityClassConstructor
+
 /**
- * Utility code for rendering images in PostScript. 
+ * Utility code for rendering images in PostScript.
  */
 public class PSImageUtils {
 
+    public PSImageUtils() {
+    }
+
     /**
      * Writes a bitmap image to the PostScript stream.
      * @param img the bitmap image as a byte array
      * @param imgDim the dimensions of the image
      * @param imgDescription the name of the image
      * @param targetRect the target rectangle to place the image in
-     * @param isJPEG true if "img" contains a DCT-encoded images, false if "img" contains the 
+     * @param isJPEG true if "img" contains a DCT-encoded images, false if "img" contains the
      *               decoded bitmap
      * @param colorSpace the color space of the image
      * @param gen the PostScript generator
@@ -58,7 +67,7 @@ public class PSImageUtils {
      */
     public static void writeImage(final byte[] img,
             Dimension imgDim, String imgDescription,
-            Rectangle2D targetRect, 
+            Rectangle2D targetRect,
             final boolean isJPEG, ColorSpace colorSpace,
             PSGenerator gen) throws IOException {
         ImageEncoder encoder = new ImageEncoder() {
@@ -76,7 +85,7 @@ public class PSImageUtils {
         };
         writeImage(encoder, imgDim, imgDescription, targetRect, colorSpace, 8, false, gen);
     }
-    
+
     /**
      * Writes a bitmap image to the PostScript stream.
      * @param encoder the image encoder
@@ -91,7 +100,7 @@ public class PSImageUtils {
      */
     public static void writeImage(ImageEncoder encoder,
             Dimension imgDim, String imgDescription,
-            Rectangle2D targetRect, 
+            Rectangle2D targetRect,
             ColorSpace colorSpace, int bitsPerComponent, boolean invertImage,
             PSGenerator gen) throws IOException {
         gen.saveGraphicsState();
@@ -103,7 +112,7 @@ public class PSImageUtils {
         // Template: (RawData is used for the EOF signal only)
         // gen.write("/RawData currentfile <first filter> filter def");
         // gen.write("/Data RawData <second filter> <third filter> [...] def");
-        String implicitFilter = encoder.getImplicitFilter(); 
+        String implicitFilter = encoder.getImplicitFilter();
         if (implicitFilter != null) {
             gen.writeln("/RawData currentfile /ASCII85Decode filter def");
             gen.writeln("/Data RawData " + implicitFilter + " filter def");
@@ -135,28 +144,31 @@ public class PSImageUtils {
         gen.restoreGraphicsState();
     }
 
+    public static void writeImage(ImageEncoder encoder, Dimension imgDim, String imgDescription,
+                                  Rectangle2D targetRect, ColorModel colorModel, PSGenerator gen) throws IOException {
+        writeImage(encoder, imgDim, imgDescription, targetRect, colorModel, gen, null);
+    }
+
     /**
      * Writes a bitmap image to the PostScript stream.
-     * @param img the bitmap image as a byte array
+     * @param encoder the image encoder
+     * @param imgDim the dimensions of the image
+     * @param imgDescription the name of the image
      * @param targetRect the target rectangle to place the image in
+     * @param colorModel the color model of the image
      * @param gen the PostScript generator
      * @throws IOException In case of an I/O exception
      */
-    private static void writeImage(RenderedImage img,
-            Rectangle2D targetRect, PSGenerator gen) throws IOException {
-        ImageEncoder encoder = ImageEncodingHelper.createRenderedImageEncoder(img);
-        String imgDescription = img.getClass().getName();
-        
+    public static void writeImage(ImageEncoder encoder, Dimension imgDim, String imgDescription,
+            Rectangle2D targetRect, ColorModel colorModel, PSGenerator gen, RenderedImage ri)
+            throws IOException {
+
         gen.saveGraphicsState();
         translateAndScale(gen, null, targetRect);
-
         gen.commentln("%AXGBeginBitmap: " + imgDescription);
-
         gen.writeln("{{");
-        // Template: (RawData is used for the EOF signal only)
-        // gen.write("/RawData currentfile <first filter> filter def");
-        // gen.write("/Data RawData <second filter> <third filter> [...] def");
-        String implicitFilter = encoder.getImplicitFilter(); 
+
+        String implicitFilter = encoder.getImplicitFilter();
         if (implicitFilter != null) {
             gen.writeln("/RawData currentfile /ASCII85Decode filter def");
             gen.writeln("/Data RawData " + implicitFilter + " filter def");
@@ -169,11 +181,22 @@ public class PSImageUtils {
                 gen.writeln("/Data RawData /RunLengthDecode filter def");
             }
         }
+
         PSDictionary imageDict = new PSDictionary();
         imageDict.put("/DataSource", "Data");
-        writeImageCommand(img, imageDict, gen);
 
-        /* the following two lines could be enabled if something still goes wrong
+        populateImageDictionary(imgDim, colorModel, imageDict);
+
+        if (ri != null) {
+            DataBuffer buffer = ri.getData().getDataBuffer();
+            if (!(buffer instanceof DataBufferByte)) {
+                imageDict.put("/BitsPerComponent", 8);
+            }
+        }
+        writeImageCommand(imageDict, colorModel, gen);
+
+        /*
+         * the following two lines could be enabled if something still goes wrong
          * gen.write("Data closefile");
          * gen.write("RawData flushfile");
          */
@@ -183,42 +206,119 @@ public class PSImageUtils {
 
         compressAndWriteBitmap(encoder, gen);
 
-        gen.writeln("");
+        gen.newLine();
         gen.commentln("%AXGEndBitmap");
         gen.restoreGraphicsState();
     }
 
-    private static ColorModel populateImageDictionary(
-                ImageEncodingHelper helper, PSDictionary imageDict) {
-        RenderedImage img = helper.getImage();
-        String w = Integer.toString(img.getWidth());
-        String h = Integer.toString(img.getHeight());
+    /**
+     * Writes a bitmap image to the PostScript stream.
+     * @param encoder the image encoder
+     * @param imgDim the dimensions of the image
+     * @param imgDescription the name of the image
+     * @param targetRect the target rectangle to place the image in
+     * @param colorModel the color model of the image
+     * @param gen the PostScript generator
+     * @throws IOException In case of an I/O exception
+     */
+    public static void writeImage(ImageEncoder encoder, Dimension imgDim, String imgDescription,
+            Rectangle2D targetRect, ColorModel colorModel, PSGenerator gen, RenderedImage ri,
+            Color maskColor)
+            throws IOException {
+
+        gen.saveGraphicsState();
+        translateAndScale(gen, null, targetRect);
+        gen.commentln("%AXGBeginBitmap: " + imgDescription);
+        gen.writeln("{{");
+
+        String implicitFilter = encoder.getImplicitFilter();
+        if (implicitFilter != null) {
+            gen.writeln("/RawData currentfile /ASCII85Decode filter def");
+            gen.writeln("/Data RawData " + implicitFilter + " filter def");
+        } else {
+            if (gen.getPSLevel() >= 3) {
+                gen.writeln("/RawData currentfile /ASCII85Decode filter def");
+                gen.writeln("/Data RawData /FlateDecode filter def");
+            } else {
+                gen.writeln("/RawData currentfile /ASCII85Decode filter def");
+                gen.writeln("/Data RawData /RunLengthDecode filter def");
+            }
+        }
+
+        PSDictionary imageDict = new PSDictionary();
+        imageDict.put("/DataSource", "Data");
+
+        populateImageDictionary(imgDim, colorModel, imageDict, maskColor);
+
+        if (ri != null) {
+            DataBuffer buffer = ri.getData().getDataBuffer();
+            if (!(buffer instanceof DataBufferByte)) {
+                imageDict.put("/BitsPerComponent", 8);
+            }
+        }
+        writeImageCommand(imageDict, colorModel, gen);
+
+        /*
+         * the following two lines could be enabled if something still goes wrong
+         * gen.write("Data closefile");
+         * gen.write("RawData flushfile");
+         */
+        gen.writeln("} stopped {handleerror} if");
+        gen.writeln("  RawData flushfile");
+        gen.writeln("} exec");
+
+        compressAndWriteBitmap(encoder, gen);
+
+        gen.newLine();
+        gen.commentln("%AXGEndBitmap");
+        gen.restoreGraphicsState();
+    }
+
+    private static ColorModel populateImageDictionary(Dimension imgDim, ColorModel colorModel,
+            PSDictionary imageDict) {
         imageDict.put("/ImageType", "1");
+        colorModel = writeImageDictionary(imgDim, imageDict, colorModel);
+        return colorModel;
+    }
+
+    private static ColorModel populateImageDictionary(Dimension imgDim, ColorModel colorModel,
+            PSDictionary imageDict, Color maskColor) {
+        imageDict.put("/ImageType", "4");
+
+        colorModel = writeImageDictionary(imgDim, imageDict, colorModel);
+        imageDict.put("/MaskColor", String.format("[ %d %d %d ]", maskColor.getRed(),
+                maskColor.getGreen(), maskColor.getBlue()));
+        return colorModel;
+    }
+
+    private static ColorModel writeImageDictionary(Dimension imgDim, PSDictionary imageDict,
+            ColorModel colorModel) {
+        String w = Integer.toString(imgDim.width);
+        String h = Integer.toString(imgDim.height);
         imageDict.put("/Width", w);
         imageDict.put("/Height", h);
-        
-        ColorModel cm = helper.getEncodedColorModel();
-        
+
         boolean invertColors = false;
-        String decodeArray = getDecodeArray(cm.getNumComponents(), invertColors);
-        int bitsPerComp = cm.getComponentSize(0);
-        
+        String decodeArray = getDecodeArray(colorModel.getNumColorComponents(), invertColors);
+        int bitsPerComp = colorModel.getComponentSize(0);
+
         // Setup scanning for left-to-right and top-to-bottom
         imageDict.put("/ImageMatrix", "[" + w + " 0 0 " + h + " 0 0]");
-        
-        if ((cm instanceof IndexColorModel)) {
-            IndexColorModel im = (IndexColorModel)cm;
-            int c = im.getMapSize();
+
+        if ((colorModel instanceof IndexColorModel)) {
+            IndexColorModel indexColorModel = (IndexColorModel) colorModel;
+            int c = indexColorModel.getMapSize();
             int hival = c - 1;
             if (hival > 4095) {
                 throw new UnsupportedOperationException("hival must not go beyond 4095");
             }
-            decodeArray = "[0 " + Integer.toString(hival) + "]";
-            bitsPerComp = im.getPixelSize();
+            bitsPerComp = indexColorModel.getPixelSize();
+            int ceiling = ((int) Math.pow(2, bitsPerComp)) - 1;
+            decodeArray = "[0 " + ceiling + "]";
         }
         imageDict.put("/BitsPerComponent", Integer.toString(bitsPerComp));
         imageDict.put("/Decode", decodeArray);
-        return cm;
+        return colorModel;
     }
 
     private static String getDecodeArray(int numComponents, boolean invertColors) {
@@ -249,26 +349,42 @@ public class PSImageUtils {
         if ((cm instanceof IndexColorModel)) {
             ColorSpace cs = cm.getColorSpace();
             IndexColorModel im = (IndexColorModel)cm;
-            gen.write("[/Indexed " + getColorSpaceName(cs));
+            boolean isDeviceGray;
             int c = im.getMapSize();
+            int[] palette = new int[c];
+            im.getRGBs(palette);
+            byte[] reds = new byte[c];
+            byte[] greens = new byte[c];
+            byte[] blues = new byte[c];
+            im.getReds(reds);
+            im.getGreens(greens);
+            im.getBlues(blues);
             int hival = c - 1;
             if (hival > 4095) {
                 throw new UnsupportedOperationException("hival must not go beyond 4095");
             }
+            isDeviceGray = Arrays.equals(reds, blues) && Arrays.equals(blues, greens);
+            if (isDeviceGray) {
+                gen.write("[/Indexed " + "/DeviceGray");
+            } else {
+                gen.write("[/Indexed " + getColorSpaceName(cs));
+            }
             gen.writeln(" " + Integer.toString(hival));
             gen.write("  <");
-            int[] palette = new int[c];
-            im.getRGBs(palette);
-            for (int i = 0; i < c; i++) {
-                if (i > 0) {
-                    if ((i % 8) == 0) {
-                        gen.newLine();
-                        gen.write("   ");
-                    } else {
-                        gen.write(" ");
+            if (isDeviceGray) {
+                gen.write(toHexString(blues));
+            } else {
+                for (int i = 0; i < c; i++) {
+                    if (i > 0) {
+                        if ((i % 8) == 0) {
+                            gen.newLine();
+                            gen.write("   ");
+                        } else {
+                            gen.write(" ");
+                        }
                     }
+                    gen.write(rgb2Hex(palette[i]));
                 }
-                gen.write(rgb2Hex(palette[i]));
             }
             gen.writeln(">");
             gen.writeln("] setcolorspace");
@@ -277,12 +393,24 @@ public class PSImageUtils {
         }
     }
 
+    static String toHexString(byte[] color) {
+        char[] hexChars = new char[color.length * 2];
+        int x;
+        for (int i = 0; i < color.length; i++) {
+            x = color[i] & 0xFF;
+            hexChars[i * 2] = HEX[x >>> 4];
+            hexChars[i * 2 + 1] = HEX[x & 0x0F];
+        }
+        return new String(hexChars);
+    }
+
     static void writeImageCommand(RenderedImage img,
             PSDictionary imageDict, PSGenerator gen) throws IOException {
-        ImageEncodingHelper helper = new ImageEncodingHelper(img);
+        ImageEncodingHelper helper = new ImageEncodingHelper(img, true);
         ColorModel cm = helper.getEncodedColorModel();
-        populateImageDictionary(helper, imageDict);
-        
+        Dimension imgDim = new Dimension(img.getWidth(), img.getHeight());
+
+        populateImageDictionary(imgDim, cm, imageDict);
         writeImageCommand(imageDict, cm, gen);
     }
 
@@ -313,7 +441,7 @@ public class PSImageUtils {
             '0', '1', '2', '3', '4', '5', '6', '7',
             '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'
         };
-    
+
     private static String rgb2Hex(int rgb) {
         StringBuffer sb = new StringBuffer();
         for (int i = 5; i >= 0; i--) {
@@ -323,7 +451,7 @@ public class PSImageUtils {
         }
         return sb.toString();
     }
-    
+
     /**
      * Renders a bitmap image to PostScript.
      * @param img image to render
@@ -334,11 +462,17 @@ public class PSImageUtils {
      * @param gen PS generator
      * @throws IOException In case of an I/O problem while rendering the image
      */
-    public static void renderBitmapImage(RenderedImage img, 
+    public static void renderBitmapImage(RenderedImage img,
                 float x, float y, float w, float h, PSGenerator gen)
                     throws IOException {
         Rectangle2D targetRect = new Rectangle2D.Double(x, y, w, h);
-        writeImage(img, targetRect, gen);
+        ImageEncoder encoder = ImageEncodingHelper.createRenderedImageEncoder(img);
+        Dimension imgDim = new Dimension(img.getWidth(), img.getHeight());
+        String imgDescription = img.getClass().getName();
+        ImageEncodingHelper helper = new ImageEncodingHelper(img);
+        ColorModel cm = helper.getEncodedColorModel();
+
+        writeImage(encoder, imgDim, imgDescription, targetRect, cm, gen, img);
     }
 
     /**
@@ -348,7 +482,7 @@ public class PSImageUtils {
      * @param imgDim the dimensions of the image
      * @param formName the name of the PostScript form to use
      * @param imageDescription a description of the image added as a DSC Title comment
-     * @param isJPEG true if "img" contains a DCT-encoded images, false if "img" contains the 
+     * @param isJPEG true if "img" contains a DCT-encoded images, false if "img" contains the
      *               decoded bitmap
      * @param colorSpace the color space of the image
      * @param gen the PostScript generator
@@ -375,7 +509,7 @@ public class PSImageUtils {
         return writeReusableImage(encoder, imgDim, formName,
                 imageDescription, colorSpace, false, gen);
     }
-    
+
     /**
      * Writes a bitmap image as a PostScript form enclosed by DSC resource wrappers to the
      * PostScript file.
@@ -404,9 +538,9 @@ public class PSImageUtils {
         if (imageDescription != null) {
             gen.writeDSCComment(DSCConstants.TITLE, imageDescription);
         }
-        
+
         String additionalFilters;
-        String implicitFilter = encoder.getImplicitFilter(); 
+        String implicitFilter = encoder.getImplicitFilter();
         if (implicitFilter != null) {
             additionalFilters = "/ASCII85Decode filter " + implicitFilter + " filter";
         } else {
@@ -438,7 +572,7 @@ public class PSImageUtils {
         PSDictionary imageDict = new PSDictionary();
         imageDict.put("/DataSource", dataSource);
         imageDict.put("/BitsPerComponent", Integer.toString(8));
-        writeImageCommand(imageDict, imgDim, colorSpace, invertImage, gen); 
+        writeImageCommand(imageDict, imgDim, colorSpace, invertImage, gen);
         gen.writeln("    grestore");
         gen.writeln("  } bind");
         gen.writeln(">> def");
@@ -454,11 +588,11 @@ public class PSImageUtils {
         compressAndWriteBitmap(encoder, gen);
         gen.writeln("def");
         gen.writeDSCComment(DSCConstants.END_RESOURCE);
-        PSResource res = new PSResource(PSResource.TYPE_FORM, formName); 
+        PSResource res = new PSResource(PSResource.TYPE_FORM, formName);
         gen.getResourceTracker().registerSuppliedResource(res);
         return res;
     }
-    
+
     /**
      * Paints a reusable image (previously added as a PostScript form).
      * @param formName the name of the PostScript form implementing the image
@@ -470,12 +604,12 @@ public class PSImageUtils {
      */
     public static void paintReusableImage(
             String formName,
-            Rectangle2D targetRect, 
+            Rectangle2D targetRect,
             PSGenerator gen) throws IOException {
         PSResource form = new PSResource(PSResource.TYPE_FORM, formName);
         paintForm(form, null, targetRect, gen);
     }
-    
+
     /**
      * Paints a reusable image (previously added as a PostScript form).
      * @param form the PostScript form resource implementing the image
@@ -487,11 +621,11 @@ public class PSImageUtils {
      */
     public static void paintForm(
             PSResource form,
-            Rectangle2D targetRect, 
+            Rectangle2D targetRect,
             PSGenerator gen) throws IOException {
         paintForm(form, null, targetRect, gen);
     }
-    
+
     /**
      * Paints a reusable image (previously added as a PostScript form).
      * @param form the PostScript form resource implementing the image
@@ -503,23 +637,23 @@ public class PSImageUtils {
     public static void paintForm(
             PSResource form,
             Dimension2D formDimensions,
-            Rectangle2D targetRect, 
+            Rectangle2D targetRect,
             PSGenerator gen) throws IOException {
         gen.saveGraphicsState();
         translateAndScale(gen, formDimensions, targetRect);
         gen.writeln(form.getName() + " execform");
-        
+
         gen.getResourceTracker().notifyResourceUsageOnPage(form);
         gen.restoreGraphicsState();
     }
-    
+
     private static String getColorSpaceName(ColorSpace colorSpace) {
         if (colorSpace.getType() == ColorSpace.TYPE_CMYK) {
-            return("/DeviceCMYK");
+            return "/DeviceCMYK";
         } else if (colorSpace.getType() == ColorSpace.TYPE_GRAY) {
-            return("/DeviceGray");
+            return "/DeviceGray";
         } else {
-            return("/DeviceRGB");
+            return "/DeviceRGB";
         }
     }
 
@@ -546,18 +680,26 @@ public class PSImageUtils {
         gen.newLine(); //Just to be sure
     }
 
-    private static void translateAndScale(PSGenerator gen,
-            Dimension2D formDimensions, Rectangle2D targetRect)
+    /**
+     * Generates commands to modify the current transformation matrix so an image fits
+     * into a given rectangle.
+     * @param gen the PostScript generator
+     * @param imageDimensions the image's dimensions
+     * @param targetRect the target rectangle
+     * @throws IOException if an I/O error occurs
+     */
+    public static void translateAndScale(PSGenerator gen,
+            Dimension2D imageDimensions, Rectangle2D targetRect)
                 throws IOException {
-        gen.writeln(gen.formatDouble(targetRect.getX()) + " " 
+        gen.writeln(gen.formatDouble(targetRect.getX()) + " "
                 + gen.formatDouble(targetRect.getY()) + " translate");
-        if (formDimensions == null) {
-            formDimensions = new Dimension(1, 1);
+        if (imageDimensions == null) {
+            imageDimensions = new Dimension(1, 1);
         }
-        double sx = targetRect.getWidth() / formDimensions.getWidth();
-        double sy = targetRect.getHeight() / formDimensions.getHeight();
+        double sx = targetRect.getWidth() / imageDimensions.getWidth();
+        double sy = targetRect.getHeight() / imageDimensions.getHeight();
         if (sx != 1 || sy != 1) {
-            gen.writeln(gen.formatDouble(sx) + " " 
+            gen.writeln(gen.formatDouble(sx) + " "
                     + gen.formatDouble(sy) + " scale");
         }
     }
@@ -601,14 +743,14 @@ public class PSImageUtils {
             data = new double[nbands];
             break;
         default:
-            throw new IllegalArgumentException("Unknown data buffer type: "+
-                                               dataType);
+            throw new IllegalArgumentException("Unknown data buffer type: "
+                                               + dataType);
         }
-        
+
         if (rgbArray == null) {
             rgbArray = new int[offset + h * scansize];
         }
-        
+
         ColorModel colorModel = img.getColorModel();
         for (int y = startY; y < startY + h; y++, yoff += scansize) {
             off = yoff;
@@ -616,10 +758,10 @@ public class PSImageUtils {
                 rgbArray[off++] = colorModel.getRGB(raster.getDataElements(x, y, data));
             }
         }
-        
+
         return rgbArray;
     }
-    
+
     /**
      * Places an EPS file in the PostScript stream.
      * @param rawEPS byte array containing the raw EPS data
@@ -645,7 +787,7 @@ public class PSImageUtils {
                new Rectangle2D.Float(bboxx, bboxy, bboxw, bboxh),
                gen);
     }
-    
+
     /**
      * Places an EPS file in the PostScript stream.
      * @param in the InputStream that contains the EPS stream
@@ -662,7 +804,7 @@ public class PSImageUtils {
         gen.writeln("%AXGBeginEPS: " + name);
         gen.writeln("BeginEPSF");
 
-        gen.writeln(gen.formatDouble(viewport.getX()) 
+        gen.writeln(gen.formatDouble(viewport.getX())
                 + " " + gen.formatDouble(viewport.getY()) + " translate");
         gen.writeln("0 " + gen.formatDouble(viewport.getHeight()) + " translate");
         gen.writeln("1 -1 scale");
@@ -680,8 +822,9 @@ public class PSImageUtils {
                 + " " + gen.formatDouble(bbox.getWidth())
                 + " " + gen.formatDouble(bbox.getHeight()) + " re clip");
         gen.writeln("newpath");
-        
+
         PSResource res = new PSResource(PSResource.TYPE_FILE, name);
+        gen.getResourceTracker().registerSuppliedResource(res);
         gen.getResourceTracker().notifyResourceUsageOnPage(res);
         gen.writeDSCComment(DSCConstants.BEGIN_DOCUMENT, res.getName());
         IOUtils.copy(in, gen.getOutputStream());
