@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: DSCParser.java 1345683 2012-06-03 14:50:33Z gadams $ */
+/* $Id: DSCParser.java 1681108 2015-05-22 13:26:12Z ssteiner $ */
 
 package org.apache.xmlgraphics.ps.dsc;
 
@@ -51,14 +51,14 @@ public class DSCParser implements DSCParserConstants {
 
     private InputStream in;
     private BufferedReader reader;
-    private boolean eofFound = false;
+    private boolean eofFound;
     private boolean checkEOF = true;
     private DSCEvent currentEvent;
     private DSCEvent nextEvent;
     private DSCListener nestedDocumentHandler;
     private DSCListener filterListener;
     private List listeners;
-    private boolean listenersDisabled = false;
+    private boolean listenersDisabled;
 
     /**
      * Creates a new DSC parser.
@@ -132,7 +132,7 @@ public class DSCParser implements DSCParserConstants {
     private DSCComment parseDSCLine(String line) throws IOException, DSCException {
         int colon = line.indexOf(':');
         String name;
-        String value = "";
+        StringBuilder value = new StringBuilder();
         if (colon > 0) {
             name = line.substring(2, colon);
             int startOfValue = colon + 1;
@@ -140,8 +140,8 @@ public class DSCParser implements DSCParserConstants {
                 if (isWhitespace(line.charAt(startOfValue))) {
                     startOfValue++;
                 }
-                value = line.substring(startOfValue).trim();
-                if (value.equals(DSCConstants.ATEND.toString())) {
+                value = new StringBuilder(line.substring(startOfValue).trim());
+                if (value.toString().equals(DSCConstants.ATEND.toString())) {
                     return new DSCAtend(name);
                 }
             }
@@ -154,14 +154,14 @@ public class DSCParser implements DSCParserConstants {
                 } else if (!nextLine.startsWith("%%+")) {
                     break;
                 }
-                value = value + nextLine.substring(3);
+                value.append(nextLine.substring(3));
             }
             this.reader.reset();
         } else {
             name = line.substring(2);
-            value = null;
+            return parseDSCComment(name, null);
         }
-        return parseDSCComment(name, value);
+        return parseDSCComment(name, value.toString());
     }
 
     private DSCComment parseDSCComment(String name, String value) {
@@ -205,9 +205,6 @@ public class DSCParser implements DSCParserConstants {
                 handler.line(getLine());
                 break;
             case EOF:
-                if (isCheckEOF()) {
-                    this.eofFound = true;
-                }
                 handler.endDocument();
                 break;
             default:
@@ -295,12 +292,12 @@ public class DSCParser implements DSCParserConstants {
     protected void parseNext() throws IOException, DSCException {
         String line = readLine();
         if (line != null) {
-            if (eofFound && (line.length() > 0)) {
+            if (isCheckEOF() && eofFound && (line.length() > 0)) {
                 throw new DSCException("Content found after EOF");
             }
             if (line.startsWith("%%")) {
                 DSCComment comment = parseDSCLine(line);
-                if (comment.getEventType() == EOF && isCheckEOF()) {
+                if (comment.getEventType() == EOF) {
                     this.eofFound = true;
                 }
                 this.nextEvent = comment;
@@ -461,12 +458,17 @@ public class DSCParser implements DSCParserConstants {
         if (handler == null) {
             removeListener(this.nestedDocumentHandler);
         } else {
-            addListener(new DSCListener() {
-                public void processEvent(DSCEvent event, DSCParser parser) throws IOException,
-                        DSCException {
-                    handler.handle(event, parser);
-                }
-            });
+            MyDSCListener l = new MyDSCListener();
+            l.handler = handler;
+            addListener(l);
+        }
+    }
+
+    static class MyDSCListener implements DSCListener {
+        private NestedDocumentHandler handler;
+        public void processEvent(DSCEvent event, DSCParser parser) throws IOException,
+                DSCException {
+            handler.handle(event, parser);
         }
     }
 
