@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: ResourceTracker.java 734420 2009-01-14 15:38:32Z maxberger $ */
+/* $Id: ResourceTracker.java 1352945 2012-06-22 16:13:25Z vhennebert $ */
 
 package org.apache.xmlgraphics.ps.dsc;
 
@@ -102,10 +102,10 @@ public class ResourceTracker {
      * @param res the resource
      */
     public void registerNeededResource(PSResource res) {
-        if (documentNeededResources == null) {
-            documentNeededResources = new java.util.HashSet();
-        }
-        if (!documentSuppliedResources.contains(res)) {
+        if (documentSuppliedResources == null || !documentSuppliedResources.contains(res)) {
+            if (documentNeededResources == null) {
+                documentNeededResources = new java.util.HashSet();
+            }
             documentNeededResources.add(res);
         }
     }
