@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: DSCCommentBoundingBox.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: DSCCommentBoundingBox.java 1681108 2015-05-22 13:26:12Z ssteiner $ */
 
 package org.apache.xmlgraphics.ps.dsc.events;
 
@@ -90,10 +90,10 @@ public class DSCCommentBoundingBox extends AbstractDSCComment {
     public void generate(PSGenerator gen) throws IOException {
         if (getBoundingBox() != null) {
             gen.writeDSCComment(getName(), new Object[] {
-                new Integer((int)Math.floor(this.bbox.getX())),
-                new Integer((int)Math.floor(this.bbox.getY())),
-                new Integer((int)Math.ceil(this.bbox.getX() + this.bbox.getWidth())),
-                new Integer((int)Math.ceil(this.bbox.getY() + this.bbox.getHeight()))});
+                    (int) Math.floor(this.bbox.getX()),
+                    (int) Math.floor(this.bbox.getY()),
+                    (int) Math.ceil(this.bbox.getX() + this.bbox.getWidth()),
+                    (int) Math.ceil(this.bbox.getY() + this.bbox.getHeight())});
         } else {
             gen.writeDSCComment(getName(), DSCConstants.ATEND);
         }
