@@ -15,18 +15,18 @@
  * limitations under the License.
  */
 
-/* $Id: ASCIIHexOutputStream.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: ASCIIHexOutputStream.java 1610846 2014-07-15 20:44:18Z vhennebert $ */
 
 package org.apache.xmlgraphics.util.io;
 
-import java.io.OutputStream;
 import java.io.FilterOutputStream;
 import java.io.IOException;
+import java.io.OutputStream;
 
 /**
  * This class applies a ASCII Hex encoding to the stream.
  *
- * @version $Id: ASCIIHexOutputStream.java 750418 2009-03-05 11:03:54Z vhennebert $
+ * @version $Id: ASCIIHexOutputStream.java 1610846 2014-07-15 20:44:18Z vhennebert $
  */
 public class ASCIIHexOutputStream extends FilterOutputStream
         implements Finalizable {
@@ -38,7 +38,7 @@ public class ASCIIHexOutputStream extends FilterOutputStream
     private static final int A     = 0x41; //"A"
     private static final int ADIFF = A - NINE - 1;
 
-    private int posinline = 0;
+    private int posinline;
 
 
     /** @see java.io.FilterOutputStream **/
