@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,13 +15,20 @@
  * limitations under the License.
  */
 
-/* $Id: Base64DecodeStream.java 496556 2007-01-16 00:59:48Z cam $ */
+/* $Id: Base64DecodeStream.java 1610846 2014-07-15 20:44:18Z vhennebert $ */
 
 package org.apache.xmlgraphics.util.io;
 
 import java.io.IOException;
 import java.io.InputStream;
 
+// CSOFF: ConstantName
+// CSOFF: MemberName
+// CSOFF: MultipleVariableDeclarations
+// CSOFF: NeedBraces
+// CSOFF: OperatorWrap
+// CSOFF: WhitespaceAround
+
 /**
  * This class implements a Base64 Character decoder as specified in RFC1113.
  * Unlike some other encoding schemes there is nothing in this encoding that
@@ -42,10 +49,9 @@ import java.io.InputStream;
  *    "Base64DecodeStream: Bad Padding byte (1)."
  * </pre>
  *
- * @author <a href="mailto:thomas.deweese@kodak.com">Thomas DeWeese</a>
- * @author <a href="mailto:vincent.hardy@eng.sun.com">Vincent Hardy</a>
- * @author      Chuck McManis
- * @version $Id: Base64DecodeStream.java 496556 2007-01-16 00:59:48Z cam $
+ * @version $Id: Base64DecodeStream.java 1610846 2014-07-15 20:44:18Z vhennebert $
+ *
+ * Originally authored by Thomas DeWeese, Vincent Hardy, and Chuck McManis.
  */
 
 public class Base64DecodeStream extends InputStream {
@@ -56,54 +62,55 @@ public class Base64DecodeStream extends InputStream {
         this.src = src;
     }
 
-    private static final byte pem_array[] = new byte[256];
+    private static final byte[] PEM_ARRAY = new byte[256];
     static {
-        for (int i=0; i<pem_array.length; i++)
-            pem_array[i] = -1;
+        for (int i = 0; i < PEM_ARRAY.length; i++) {
+            PEM_ARRAY[i] = -1;
+        }
 
         int idx = 0;
-        for (char c='A'; c<='Z'; c++) {
-            pem_array[c] = (byte)idx++;
+        for (char c = 'A'; c <= 'Z'; c++) {
+            PEM_ARRAY[c] = (byte)idx++;
         }
-        for (char c='a'; c<='z'; c++) {
-            pem_array[c] = (byte)idx++;
+        for (char c = 'a'; c <= 'z'; c++) {
+            PEM_ARRAY[c] = (byte)idx++;
         }
 
-        for (char c='0'; c<='9'; c++) {
-            pem_array[c] = (byte)idx++;
+        for (char c = '0'; c <= '9'; c++) {
+            PEM_ARRAY[c] = (byte)idx++;
         }
 
-        pem_array['+'] = (byte)idx++;
-        pem_array['/'] = (byte)idx++;
+        PEM_ARRAY['+'] = (byte)idx++;
+        PEM_ARRAY['/'] = (byte)idx++;
     }
 
     public boolean markSupported() { return false; }
 
     public void close()
         throws IOException {
-        EOF = true;
+        eof = true;
     }
 
     public int available()
         throws IOException {
-        return 3-out_offset;
+        return 3 - outOffset;
     }
 
-    byte decode_buffer[] = new byte[4];
-    byte out_buffer[] = new byte[3];
-    int  out_offset = 3;
-    boolean EOF = false;
+    byte[] decodeBuffer = new byte[4];
+    byte[] outBuffer = new byte[3];
+    int  outOffset = 3;
+    boolean eof;
 
     public int read() throws IOException {
 
-        if (out_offset == 3) {
-            if (EOF || getNextAtom()) {
-                EOF = true;
+        if (outOffset == 3) {
+            if (eof || getNextAtom()) {
+                eof = true;
                 return -1;
             }
         }
 
-        return ((int)out_buffer[out_offset++])&0xFF;
+        return ((int)outBuffer[outOffset++]) & 0xFF;
     }
 
     public int read(byte []out, int offset, int len)
@@ -111,15 +118,18 @@ public class Base64DecodeStream extends InputStream {
 
         int idx = 0;
         while (idx < len) {
-            if (out_offset == 3) {
-                if (EOF || getNextAtom()) {
-                    EOF = true;
-                    if (idx == 0) return -1;
-                    else          return idx;
+            if (outOffset == 3) {
+                if (eof || getNextAtom()) {
+                    eof = true;
+                    if (idx == 0) {
+                        return -1;
+                    } else {
+                        return idx;
+                    }
                 }
             }
 
-            out[offset+idx] = out_buffer[out_offset++];
+            out[offset + idx] = outBuffer[outOffset++];
 
             idx++;
         }
@@ -127,49 +137,56 @@ public class Base64DecodeStream extends InputStream {
     }
 
     final boolean getNextAtom() throws IOException {
-        int count, a, b, c, d;
+        int count;
+        int a;
+        int b;
+        int c;
+        int d;
 
         int off = 0;
-        while(off != 4) {
-            count = src.read(decode_buffer, off, 4-off);
-            if (count == -1)
+        while (off != 4) {
+            count = src.read(decodeBuffer, off, 4 - off);
+            if (count == -1) {
                 return true;
+            }
 
-            int in=off, out=off;
-            while(in < off+count) {
-                if ((decode_buffer[in] != '\n') &&
-                    (decode_buffer[in] != '\r') &&
-                    (decode_buffer[in] != ' '))
-                    decode_buffer[out++] = decode_buffer[in];
+            int in = off;
+            int out = off;
+            while (in < off + count) {
+                if ((decodeBuffer[in] != '\n')
+                    && (decodeBuffer[in] != '\r')
+                    && (decodeBuffer[in] != ' ')) {
+                    decodeBuffer[out++] = decodeBuffer[in];
+                }
                 in++;
             }
 
             off = out;
         }
 
-        a = pem_array[((int)decode_buffer[0])&0xFF];
-        b = pem_array[((int)decode_buffer[1])&0xFF];
-        c = pem_array[((int)decode_buffer[2])&0xFF];
-        d = pem_array[((int)decode_buffer[3])&0xFF];
+        a = PEM_ARRAY[((int)decodeBuffer[0]) & 0xFF];
+        b = PEM_ARRAY[((int)decodeBuffer[1]) & 0xFF];
+        c = PEM_ARRAY[((int)decodeBuffer[2]) & 0xFF];
+        d = PEM_ARRAY[((int)decodeBuffer[3]) & 0xFF];
 
-        out_buffer[0] = (byte)((a<<2) | (b>>>4));
-        out_buffer[1] = (byte)((b<<4) | (c>>>2));
-        out_buffer[2] = (byte)((c<<6) |  d     );
+        outBuffer[0] = (byte)((a << 2) | (b >>> 4));
+        outBuffer[1] = (byte)((b << 4) | (c >>> 2));
+        outBuffer[2] = (byte)((c << 6) |  d);
 
-        if (decode_buffer[3] != '=') {
+        if (decodeBuffer[3] != '=') {
             // All three bytes are good.
-            out_offset=0;
-        } else if (decode_buffer[2] == '=') {
+            outOffset = 0;
+        } else if (decodeBuffer[2] == '=') {
             // Only one byte of output.
-            out_buffer[2] = out_buffer[0];
-            out_offset = 2;
-            EOF=true;
+            outBuffer[2] = outBuffer[0];
+            outOffset = 2;
+            eof = true;
         } else {
             // Only two bytes of output.
-            out_buffer[2] = out_buffer[1];
-            out_buffer[1] = out_buffer[0];
-            out_offset = 1;
-            EOF=true;
+            outBuffer[2] = outBuffer[1];
+            outBuffer[1] = outBuffer[0];
+            outOffset = 1;
+            eof = true;
         }
 
         return false;
