@@ -15,20 +15,21 @@
  * limitations under the License.
  */
 
-/* $Id: RunLengthEncodeOutputStream.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: RunLengthEncodeOutputStream.java 1610846 2014-07-15 20:44:18Z vhennebert $ */
 
 package org.apache.xmlgraphics.util.io;
 
 import java.io.FilterOutputStream;
-import java.io.OutputStream;
 import java.io.IOException;
+import java.io.OutputStream;
 
 
 /**
  * This class applies a RunLengthEncode filter to the stream.
  *
- * @author   <a href="mailto:smwolke@geistig.com">Stephen Wolke</a>
- * @version  $Id: RunLengthEncodeOutputStream.java 750418 2009-03-05 11:03:54Z vhennebert $
+ * @version  $Id: RunLengthEncodeOutputStream.java 1610846 2014-07-15 20:44:18Z vhennebert $
+ *
+ * Originally authored by Stephen Wolke.
  */
 public class RunLengthEncodeOutputStream extends FilterOutputStream
             implements Finalizable {
@@ -42,7 +43,7 @@ public class RunLengthEncodeOutputStream extends FilterOutputStream
     private static final int IN_SEQUENCE           = 2;
     private static final int NOT_IN_SEQUENCE       = 3;
 
-    private int runCount = 0;
+    private int runCount;
     private int isSequence = NOT_IDENTIFY_SEQUENCE;
     private byte[] runBuffer = new byte[MAX_SEQUENCE_COUNT + 1];
 
@@ -97,17 +98,6 @@ public class RunLengthEncodeOutputStream extends FilterOutputStream
             break;
         default:
             switch (isSequence) {
-            case IN_SEQUENCE:
-                if (runBuffer[runCount] != runBuffer[runCount - 1]) {
-                    out.write(BYTE_MAX - (runCount - 1));
-                    out.write(runBuffer[runCount - 1]);
-                    runBuffer[0] = runBuffer[runCount];
-                    runCount = 1;
-                    isSequence = NOT_IDENTIFY_SEQUENCE;
-                    break;
-                }
-                runCount++;
-                break;
             case NOT_IN_SEQUENCE:
                 if (runBuffer[runCount] == runBuffer[runCount - 1]) {
                     isSequence = START_SEQUENCE;
@@ -129,6 +119,18 @@ public class RunLengthEncodeOutputStream extends FilterOutputStream
                     runCount++;
                     break;
                 }
+            case IN_SEQUENCE:
+            default:
+                if (runBuffer[runCount] != runBuffer[runCount - 1]) {
+                    out.write(BYTE_MAX - (runCount - 1));
+                    out.write(runBuffer[runCount - 1]);
+                    runBuffer[0] = runBuffer[runCount];
+                    runCount = 1;
+                    isSequence = NOT_IDENTIFY_SEQUENCE;
+                    break;
+                }
+                runCount++;
+                break;
             }
         }
     }
