@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: XMPSchemaAdapter.java 1336053 2012-05-09 10:11:45Z gadams $ */
+/* $Id: XMPSchemaAdapter.java 1695310 2015-08-11 14:37:52Z ssteiner $ */
 
 package org.apache.xmlgraphics.xmp;
 
@@ -33,6 +33,7 @@ public class XMPSchemaAdapter {
     /** the Metadata object this schema instance operates on */
     protected Metadata meta;
     private XMPSchema schema;
+    private boolean compact = true;
 
     /**
      * Main constructor.
@@ -92,6 +93,9 @@ public class XMPSchemaAdapter {
         if (prop == null) {
             prop = new XMPProperty(name, value);
             meta.setProperty(prop);
+            if (!compact) {
+                prop.convertSimpleValueToArray(arrayType);
+            }
         } else {
             prop.convertSimpleValueToArray(arrayType);
             prop.getArrayValue().add(value);
@@ -439,5 +443,7 @@ public class XMPSchemaAdapter {
         return res;
     }
 
-
+    public void setCompact(boolean c) {
+        compact = c;
+    }
 }
