@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: ASCII85InputStreamTestCase.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: ASCII85InputStreamTestCase.java 1365650 2012-07-25 15:59:30Z mehdi $ */
 
 package org.apache.xmlgraphics.util.io;
 
@@ -23,13 +23,16 @@ import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
+
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.io.output.ByteArrayOutputStream;
 
 import org.apache.xmlgraphics.util.HexUtil;
 
-import junit.framework.TestCase;
-
 /**
  * Test case for ASCII85InputStream.
  * <p>
@@ -37,17 +40,10 @@ import junit.framework.TestCase;
  * ASCII85OutputStream. If something fails here make sure
  * ASCII85OutputStreamTestCase runs!
  */
-public class ASCII85InputStreamTestCase extends TestCase {
+public class ASCII85InputStreamTestCase {
 
     private static final boolean DEBUG = false;
 
-    /**
-     * @see junit.framework.TestCase#TestCase(String)
-     */
-    public ASCII85InputStreamTestCase(String name) {
-        super(name);
-    }
-
     private byte[] decode(String text) throws Exception {
         byte[] ascii85 = text.getBytes("US-ASCII");
         InputStream in = new ByteArrayInputStream(ascii85);
@@ -97,8 +93,8 @@ public class ASCII85InputStreamTestCase extends TestCase {
      * Tests the output of ASCII85.
      * @throws Exception if an error occurs
      */
+    @Test
     public void testDecode() throws Exception {
-        byte[] buf;
         innerTestDecode("1. Bodypart".getBytes("US-ASCII"));
         if (DEBUG) {
             System.out.println("===========================================");
@@ -160,6 +156,7 @@ public class ASCII85InputStreamTestCase extends TestCase {
      * Tests the full 8-bit ASCII range.
      * @throws Exception if an error occurs
      */
+    @Test
     public void testFullASCIIRange() throws Exception {
         innerTestDecode(getFullASCIIRange());
     }
